@@ -202,13 +202,13 @@ $(function(){
 					}
 				}
 
-				var content = '<div class="section activity-section group" data-date="' + escapeHTML(dayOfYear) + '">' + "\n"
-					+'	<h2>'+"\n"
-					+'		<span class="has-tooltip" title="' + escapeHTML(dateOfDay) + '">' + escapeHTML(displayDate) + '</span>' + "\n"
-					+'	</h2>' + "\n"
-					+'	<div class="boxcontainer">' + "\n"
-					+'	</div>' + "\n"
-					+'</div>';
+				var header = '<h2 class="section-header" title="' + escapeHTML(dateOfDay) + '">' + escapeHTML(displayDate) + '</h2>'
+					+'	<span class="hidden-visually">' + escapeHTML(dateOfDay) + '</span>' + "\n";
+				var content = '<ul class="section activity-section group" data-date="' + escapeHTML(dayOfYear) + '">' + '</ul>';
+				var $header = $(header);
+				this.processElements($header);
+				this.$container.append($header);
+
 				var $content = $(content);
 				this.processElements($content);
 				this.$container.append($content);
@@ -232,7 +232,7 @@ $(function(){
 			var monochromeIcon = activity.type !== 'file_created' && activity.type !== 'file_deleted' && activity.type !== 'favorite' && !activity.icon.endsWith('-color.svg');
 
 			var content = ''
-				+ '<div class="activity box" data-activity-id="' + activity.activity_id + '">' + "\n"
+				+ '<li class="activity box" data-activity-id="' + activity.activity_id + '">' + "\n"
 				+ '	<div class="messagecontainer">' + "\n"
 
 				+ '		<div class="activity-icon' + ((monochromeIcon) ? ' monochrome' : '') +'">'
@@ -245,7 +245,11 @@ $(function(){
 				+ ((activity.link) ? '			</a>' + "\n" : '')
 				+ '		</div>' + "\n"
 
-				+'		<span class="activitytime has-tooltip live-relative-timestamp" data-timestamp="' + activity.timestamp + '" title="' + escapeHTML(OC.Util.formatDate(activity.timestamp)) + '">' + "\n"
+				+'		<span class="hidden-visually">' + "\n"
+				+ '			' + escapeHTML(OC.Util.formatDate(activity.timestamp)) + "\n"
+				+'		</span>' + "\n"
+
+				+'		<span class="activitytime live-relative-timestamp" data-timestamp="' + activity.timestamp + '" title="' + escapeHTML(OC.Util.formatDate(activity.timestamp)) + '">' + "\n"
 				+ '			' + escapeHTML(OC.Util.relativeModifiedDate(activity.timestamp)) + "\n"
 				+'		</span>' + "\n";
 
@@ -267,7 +271,7 @@ $(function(){
 			}
 
 			content += '	</div>' + "\n"
-				+'</div>';
+				+'</li>';
 
 			var $content = $(content);
 			this.processElements($content);
@@ -304,9 +308,6 @@ $(function(){
 				self.processElements($subject);
 			});
 
-			$element.find('.has-tooltip').tooltip({
-				placement: 'bottom'
-			});
 		}
 	};
 
