@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Парола за отдалечено споделяне",
     "Cancel" : "Отказ",
     "Add remote share" : "Добави отдалечено споделяне",
-    "Copy" : "Копиране",
-    "Copied!" : "Копирано!",
-    "Not supported!" : "Не се поддържа!",
-    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
-    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
     "Invalid Federated Cloud ID" : "Невалиден Federated Cloud ID",
     "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
     "Couldn't establish a federated share." : "Неуспешно осъществяване на федерално споделяне",
@@ -25,15 +20,11 @@ OC.L10N.register(
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Неуспешно споделяне на %1$s, не можа да се намери %2$s, може би сървърът в момента е недостъпен или използва самоподписан сертификат.",
     "Could not find share" : "Споделянето не можа да се намери",
     "Federated sharing" : "Федерално споделяне",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Получихте „%3$s“, като отдалечен дял от %4$s (%1$s) (от името на %5$s (%2$s))",
     "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Получихте {share} като отдалечено споделяне от {user} (от името на {behalf})",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Получихте „%3$s“, като отдалечено споделяне от %4$s (%1$s)",
     "You received {share} as a remote share from {user}" : "Получихте {share}, като отдалечено споделяне от {user}",
     "Accept" : "Приемам",
     "Decline" : "Отхвърляне",
     "Federated Cloud Sharing" : "Федерирано споделяне в облак",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID - %s",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID",
     "Sharing" : "Споделяне",
     "Federated file sharing" : "Федерирано споделяне на файлове",
     "Provide federated file sharing across servers" : "Осигуряване на федерирано споделяне на файлове между сървъри",
@@ -44,14 +35,30 @@ OC.L10N.register(
     "Allow users on this server to receive group shares from other servers" : "Позволете на потребители на този сървър да получават групови споделяния от други сървъри",
     "Search global and public address book for users" : "Търсене на глобална и публична адресна книга за потребители",
     "Allow users to publish their data to a global and public address book" : "Позволете на потребителите да публикуват своите данни в глобална и публична адресна книга",
+    "Unable to update federated files sharing config" : "Не може да се актуализира конфигурацията за споделяне на обединени файлове",
     "Federated Cloud" : "Федериран облак",
-    "Open documentation" : "Отвори документацията",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете да споделяте с всеки, който използва сървър Nextcloud или други сървъри и услуги, съвместими с Open Cloud Mesh (OCM)! Просто поставете техния идентификатор за Федериран облак в диалоговия прозорец за споделяне. Изглежда като person@cloud.example.com",
     "Your Federated Cloud ID:" : "Вашият Federated Cloud ID:",
     "Share it so your friends can share files with you:" : "Споделете, за да могат приятелите ви да споделят файлове, с вас:",
+    "Facebook" : "Фейсбук",
+    "Twitter" : "Twitter",
+    "Diaspora" : "Диаспора",
     "Add to your website" : "Добавете към вашия уеб сайт",
     "Share with me via Nextcloud" : "Споделете с мен, чрез Nextcloud",
     "HTML Code:" : "HTML код:",
-    "Adjust how people can share between servers." : "Настройка на начина по който хората могат да споделят между сървърите. "
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Споделете с мен чрез моя #Nextcloud Federated Cloud ID, вижте {url}",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID",
+    "Cloud ID copied to the clipboard" : "Cloud идентификатора е копиран в клипборда",
+    "Copy to clipboard" : "Копиране в клипборда",
+    "Clipboard is not available" : "Клипбордът не е достъпен",
+    "Copied!" : "Копирано!",
+    "Copy" : "Копиране",
+    "Not supported!" : "Не се поддържа!",
+    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
+    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Получихте „%3$s“, като отдалечен дял от %4$s (%1$s) (от името на %5$s (%2$s))",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Получихте „%3$s“, като отдалечено споделяне от %4$s (%1$s)",
+    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID - %s",
+    "Open documentation" : "Отвори документацията"
 },
 "nplurals=2; plural=(n != 1);");
