@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Лозинка за далечинско споделување",
     "Cancel" : "Откажи",
     "Add remote share" : "Додади далечинско споделување",
-    "Copy" : "Копирај",
-    "Copied!" : "Копирано!",
-    "Not supported!" : "Не е поддржано!",
-    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
-    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
     "Invalid Federated Cloud ID" : "Невалиден федерален ID",
     "Server to server sharing is not enabled on this server" : "Споделување од сервер на сервервер не е овозможено на овој сервер",
     "Couldn't establish a federated share." : "Неможе да се воспостави федерално споделување.",
@@ -18,38 +13,52 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Испратено е барање за федерално споделување, ќе добиете покана. Проверете ги известувањата.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Неможе да се воспостави федерално споделување, изгледа дека Федералноиот сервер има премногу стара верзија (<= 9).",
     "It is not allowed to send federated group shares from this server." : "Не е овозможено да испратите федерално групно споделување од овој сервер.",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Споделувањето на %1$s е неуспешно, бидејќи истото веќе е споделено со корисникот %2$s",
     "Not allowed to create a federated share with the same user" : "Не е овозможено да креирате федерално споделување со ист корисник",
+    "Federated shares require read permissions" : "Федералното споделување бара дозволи за читање",
     "File is already shared with %s" : "Датотеката е веќе споделена со %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Споделувањето на %1$s е неуспешно, неможе да се пронајде %2$s, можеби серверот моментално не е достапен или користи недоверлив сертификат.",
     "Could not find share" : "Неможе да се пронајде споделувањето",
     "Federated sharing" : "Федерално споделување",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Примивте \"%3$s\" како далечинско споделување од %4$s (%1$s) (во име на %5$s (%2$s))",
     "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Добивте {share} како далечинско споделување од {user} (во име на {behalf})",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Примивте \"%3$s\" како далечинско споделување од %4$s (%1$s)",
     "You received {share} as a remote share from {user}" : "Добивте {share} како далечинско споделување од {user}",
     "Accept" : "Прифати",
     "Decline" : "Одбиј",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Споделете со мене преку мојот Федерален Cloud ID, види %s",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете со мене преку мојот Федерален Cloud ID",
+    "Federated Cloud Sharing" : "Федерално споделување",
     "Sharing" : "Споделување",
     "Federated file sharing" : "Федерално споделување на датотеки",
     "Provide federated file sharing across servers" : "Обезбедете федерално споделување на датотеки помеѓу сервери",
-    "Federated Cloud Sharing" : "Федерално споделување",
-    "Open documentation" : "Отвори ја документацијата",
-    "Adjust how people can share between servers." : "Прилагодете како корисниците можат да споделуваат помеѓу серверите.",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Прилагодете како луѓето можат да споделуваат помеѓу серверите. Ова ги вклучува споделувањата помеѓу корисниците на овој сервер, како и доколку користат федерално споделување.",
     "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со други сервери (оваа можност истотака дозволува WebDAV пристап до јавни споделувања)",
     "Allow users on this server to receive shares from other servers" : "Дозволи им на корисниците на овој сервер да примаат споделувања од други сервери",
     "Allow users on this server to send shares to groups on other servers" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со групи на други сервери",
     "Allow users on this server to receive group shares from other servers" : "Дозволи им на корисниците на овој сервер да примаат споделувања од групи од други сервери",
     "Search global and public address book for users" : "Пребарајте го глобалниот и јавниот именик на корисници",
     "Allow users to publish their data to a global and public address book" : "Дозволи им на корисниците да објавуваат информации во глобалниот и јавниот именик ",
+    "Unable to update federated files sharing config" : "Неможе да се ажурираат параметрите за федерално споделување",
     "Federated Cloud" : "Федерален клауд",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете да споделувате со секој што користи Nextcloud сервер или друг вид на Open Cloud Mesh (OCM) компатибилен сервер или сервис! Само внесете го федералниот ID во полето за споделување. Треба да изгледа korisnik@cloud.primer.com",
     "Your Federated Cloud ID:" : "Вашиот федерален ID:",
     "Share it so your friends can share files with you:" : "Споделете и вашите пријатели ќе можат да споделуваат со вас:",
+    "Facebook" : "Facebook",
+    "Twitter" : "Twitter",
+    "Diaspora" : "Diaspora",
     "Add to your website" : "Додади на твојот веб сајт",
     "Share with me via Nextcloud" : "Сподели со мене",
     "HTML Code:" : "HTML код:",
-    "Allow users on this server to send shares to other servers" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со други сервери"
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Споделете со мене преку мојот Федерален Cloud ID, види {url}",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете со мене преку мојот Федерален Cloud ID",
+    "Cloud ID copied to the clipboard" : "Cloud ID е копиран во клипборд",
+    "Copy to clipboard" : "Копирај во клипборд",
+    "Clipboard is not available" : "Клипбордот не е достапен",
+    "Copied!" : "Копирано!",
+    "Copy" : "Копирај",
+    "Not supported!" : "Не е поддржано!",
+    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
+    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Примивте \"%3$s\" како далечинско споделување од %4$s (%1$s) (во име на %5$s (%2$s))",
+    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Примивте \"%3$s\" како далечинско споделување од %4$s (%1$s)",
+    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Споделете со мене преку мојот Федерален Cloud ID, види %s",
+    "Open documentation" : "Отвори ја документацијата"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
