@@ -1,13 +1,13 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
-    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
-    "Unknown error" : "Άγνωστο σφάλμα",
     "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
     "Move or copy" : "Μετακίνηση ή αντιγραφή",
     "Download" : "Λήψη",
     "Delete" : "Διαγραφή",
+    "Tags" : "Ετικέτες",
+    "Show list view" : "Προβολή λίστας",
+    "Show grid view" : "Προβολή πλέγματος",
     "Home" : "Αρχική",
     "Close" : "Κλείσιμο",
     "Favorites" : "Αγαπημένα",
@@ -30,8 +30,10 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Σφάλμα κατά την συλλογή τμημάτων, κωδικός κατάστασης {status}",
     "Actions" : "Ενέργειες",
     "Rename" : "Μετονομασία",
+    "Move" : "Μετακίνηση",
     "Copy" : "Αντιγραφή",
     "Choose target folder" : "Επιλογή φακέλου προορισμού",
+    "Edit locally" : "Επεξεργασία τοπικά",
     "Open" : "Άνοιγμα",
     "Delete file" : "Διαγραφή αρχείου",
     "Delete folder" : "Διαγραφή φακέλου",
@@ -48,6 +50,7 @@ OC.L10N.register(
     "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας",
     "This operation is forbidden" : "Αυτή η λειτουργία απαγορεύεται",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
+    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
     "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
     "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
     "copy" : "αντιγραφή",
@@ -55,7 +58,8 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
     "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
-    "{newName} already exists" : "Το {newname} υπάρχει ήδη",
+    "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
+    "{newName} already exists" : "Το {newName} υπάρχει ήδη",
     "Could not rename \"{fileName}\", it does not exist any more" : "Αδυναμία μετονομασίας του \"{fileName}\", το αρχείο δεν υπάρχει πια.",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
     "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
@@ -75,8 +79,9 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
     "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
-    "New" : "Νέο",
+    "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
     "Select file range" : "Επιλέξτε εύρος αρχείων",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "Χρήση {used} από {quota} ",
     "{used} used" : "Σε χρήση {used}",
     "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
@@ -93,12 +98,11 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός σας χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Ταιριάζει \"{filter}\"","Ταιριάζουν \"{filter}\""],
     "View in folder" : "Προβολή στον φάκελο",
-    "Copied!" : "Αντιγράφηκε!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
     "Path" : "Διαδρομή",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Αγαπημένα",
     "Favorite" : "Αγαπημένο",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
     "You can only favorite a single file or folder at a time" : "Προσθήκη στα αγαπημένα ενός αρχείου ή φακέλου κάθε φορά",
     "New folder" : "Νέος φάκελος",
     "Upload file" : "Μεταφόρτωση αρχείου",
@@ -148,7 +152,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Ένα αγαπημένο αρχείο ή φάκελός σας έχει <strong>τροποποιηθεί</strong>.",
     "All files" : "Όλα τα αρχεία",
-    "Unlimited" : "Απεριόριστο",
     "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
     "Accept" : "Αποδοχή",
     "Reject" : "Απόρριψη",
@@ -171,9 +174,17 @@ OC.L10N.register(
     "Transfer" : "Μεταφορά",
     "Transfer {path} to {userid}" : "Μεταφορά {path} στον {userid}",
     "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
+    "Unknown error" : "Άγνωστο σφάλμα",
     "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
     "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
-    "Tags" : "Ετικέτες",
+    "Files settings" : "Ρυθμίσεις αρχείων",
+    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
+    "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
+    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
+    "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
+    "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
     "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
     "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
     "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
@@ -186,14 +197,6 @@ OC.L10N.register(
     "Set up templates folder" : "Ρύθμιση φακέλου προτύπων",
     "Templates" : "Πρότυπα",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
-    "%s used" : "%s σε χρήση",
-    "%s%% of %s used" : "%s%% από %s σε χρήση",
-    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
-    "Settings" : "Ρυθμίσεις",
-    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
-    "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
     "Toggle %1$s sublist" : "Εναλλαγή %1$s σε υπολίστα",
     "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
     "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
@@ -213,8 +216,16 @@ OC.L10N.register(
     "Pending shares" : "Κοινή χρήση σε εκκρεμότητα",
     "Text file" : "Αρχείο κειμένου",
     "New text file.txt" : "Νέο αρχείο file.txt",
+    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
     "Select" : "Επιλογή",
     "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
-    "Cannot transfer ownership of a file or folder you don't own" : "Δεν μπορεί να μεταβιβαστεί η κυριότητα αρχείου ή φακέλου που δεν σας ανήκει"
+    "New" : "Νέο",
+    "Copied!" : "Αντιγράφηκε!",
+    "Unlimited" : "Απεριόριστο",
+    "Cannot transfer ownership of a file or folder you don't own" : "Δεν μπορεί να μεταβιβαστεί η κυριότητα αρχείου ή φακέλου που δεν σας ανήκει",
+    "%s used" : "%s σε χρήση",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
+    "Settings" : "Ρυθμίσεις"
 },
 "nplurals=2; plural=(n != 1);");
