@@ -26,13 +26,17 @@ OC.L10N.register(
     "Something happened. Unable to accept the share." : "Der skete et eller andet. Ude af stand til at acceptere delingen.",
     "Reject share" : "Afvis deling",
     "Something happened. Unable to reject the share." : "Der skete et eller andet. Ude af stand til at afvise delingen.",
+    "Waiting…" : "Venter …",
     "error" : "fejl",
+    "finished" : "Færdiggjort",
     "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
     "Move or copy" : "Flyt eller kopier",
     "Download" : "Hent",
     "Delete" : "Slet",
     "You can upload into this folder" : "Du kan overføre til denne mappe",
     "Terms of service" : "Servicebetingelser",
+    "Show list view" : "Vis som liste",
+    "Show grid view" : "Vis som gitter",
     "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
     "Invalid server URL" : "Ugyldig server adresse",
     "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
@@ -96,11 +100,12 @@ OC.L10N.register(
     "Files" : "Filer",
     "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
     "Shared link" : "Delt link",
-    "Wrong share ID, share doesn't exist" : "Forkert DelingsID, deling findes ikke",
+    "Wrong share ID, share does not exist" : "Forkert DelingsID, deling findes ikke",
     "Could not delete share" : "Kunne ikke slette deling",
     "Please specify a file or folder path" : "Præciser venligst en fil eller mappesti",
-    "Wrong path, file/folder doesn't exist" : "Forkert sti, fil/mappe findes ikke",
-    "invalid permissions" : "Ugyldige rettigheder",
+    "Wrong path, file/folder does not exist" : "Forkert sti, fil/mappe findes ikke",
+    "Could not create share" : "Kunne ikke oprette deling",
+    "Invalid permissions" : "Ugyldige rettigheder",
     "Please specify a valid user" : "Angiv en gyldig bruger",
     "Group sharing is disabled by the administrator" : "Gruppedeling er deaktiveret af administratoren",
     "Please specify a valid group" : "Angiv en gyldig gruppe",
@@ -113,16 +118,27 @@ OC.L10N.register(
     "Wrong or no update parameter given" : "Forkert eller manglende opdateringsparameter",
     "shared by %s" : "deles af %s",
     "Direct link" : "Direkte link",
-    "Add to your Nextcloud" : "Tilføj til din Nextcloud",
     "Share API is disabled" : "Delings-API er slået fra",
     "File sharing" : "Fildeling",
     "Accept" : "Accepter",
     "Reject" : "Afvis",
     "Sharing" : "Deling",
+    "Reset" : "Nulstil",
+    "Invalid path selected" : "Ugyldig sti valgt.",
+    "Unknown error" : "Ukendt fejl",
     "Allow editing" : "Tillad redigering",
+    "Read only" : "Skrivebeskyttet",
+    "Allow upload and editing" : "Tillad upload og redigering",
+    "File drop (upload only)" : "Fil drop (kun upload)",
+    "Read" : "Læst",
+    "Upload" : "Send",
+    "Edit" : "Rediger",
+    "Allow creating" : "Tillad oprettelse",
+    "Allow deleting" : "Tillad sletning",
     "Allow resharing" : "Tillad videredeling",
     "Expiration date enforced" : "Udløbsdato tvungen",
     "Set expiration date" : "Angiv udløbsdato",
+    "Enter a date" : "Indtast en dato",
     "Note to recipient" : "Note til modtager",
     "Unshare" : "Fjern deling",
     "group" : "gruppe",
@@ -131,28 +147,33 @@ OC.L10N.register(
     "remote group" : "ekstern gruppe",
     "guest" : "Gæst",
     "Internal link" : "Internt link",
-    "Link copied" : "Link kopieret",
-    "Copy to clipboard" : "Kopier til udklipsholder",
+    "Cannot copy, please copy the link manually" : "Kan ikke kopiere, kopier venligst linket manuelt",
     "Only works for users with access to this folder" : "Virker kun for brugere med adgang til denne folder",
     "Only works for users with access to this file" : "Virker kun for brugere med adgang til denne fil",
+    "Link copied" : "Link kopieret",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Cancel" : "Annullér",
-    "Read only" : "Skrivebeskyttet",
-    "Allow upload and editing" : "Tillad upload og redigering",
-    "File drop (upload only)" : "Fil drop (kun upload)",
     "Hide download" : "Skjul download",
     "Password protect" : "Beskyt med adgangskode",
     "Add another link" : "Tilføj et link mere",
     "Create a new share link" : "Opret et nyt delingslink",
     "Share link" : "Share link",
+    "No recommendations. Start typing." : "Ingen anbefalinger. Begynd at skrive.",
     "Resharing is not allowed" : "Gendeling er ikke tilladt",
     "Searching …" : "Søger ...",
+    "No elements found." : "Ingen elementer fundet.",
     "Search globally" : "Søg globalt",
+    "Guest" : "Gæst",
+    "Group" : "Gruppe",
+    "Email" : "E-mail",
+    "Circle" : "Cirkel",
     "Others with access" : "Andre med adgang",
     "No other users with access found" : "Ingen andre brugere med adgang fundet",
     "Toggle list of others with access to this directory" : "Vis/skjul liste over andre med adgang til denne mappe",
     "Toggle list of others with access to this file" : "Vis/skjul liste over andre med adgang til denne fil",
+    "Shared with you by {owner}" : "Delt med dig {owner}",
+    "Error creating the share" : "Fejl ved skabelse af delt drev",
     "Shared" : "Delt",
     "Share" : "Del",
     "Shared with" : "Delt med",
@@ -160,23 +181,24 @@ OC.L10N.register(
     "Shared with you and {circle} by {owner}" : "Delt med dig og {circle} af {owner}",
     "Shared with you and the conversation {conversation} by {owner}" : "Delt med dig og konversationen {conversation} af {owner}",
     "Shared with you in a conversation by {owner}" : "Delt med dig og konversationen af {owner}",
-    "Shared with you by {owner}" : "Delt med dig {owner}",
     "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
     "Name" : "Navn",
     "Share time" : "Dele periode",
     "Expiration date" : "Udløbsdato",
-    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
     "Reasons might be:" : "Årsagen kan være:",
     "the item was removed" : "Filen blev fjernet",
     "the link expired" : "linket udløb",
     "sharing is disabled" : "deling er deaktiveret",
     "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
     "Share note" : "Del note",
-    "Toggle grid view" : "Vis som liste",
-    "Download %s" : "Hent %s",
     "Upload files to %s" : "Upload filer til %s",
     "Note" : "Note",
     "Select or drop files" : "Vælg eller slip filer",
-    "Uploaded files:" : "Uploadede filer:"
+    "Uploaded files:" : "Uploadede filer:",
+    "Add to your Nextcloud" : "Tilføj til din Nextcloud",
+    "Wrong share ID, share doesn't exist" : "Forkert DelingsID, deling findes ikke",
+    "Copy to clipboard" : "Kopier til udklipsholder",
+    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
+    "Toggle grid view" : "Vis som liste"
 },
 "nplurals=2; plural=(n != 1);");
