@@ -25,21 +25,25 @@ OC.L10N.register(
     "Accept share" : "Hyväksy jako",
     "Something happened. Unable to accept the share." : "Jotain tapahtui. Jakoa ei voitu hyväksyä.",
     "Reject share" : "Hylkää jako",
+    "Something happened. Unable to reject the share." : "Tapahtui virhe. Ei voida hylätä jakoa.",
     "Waiting…" : "Odotetaan…",
     "error" : "virhe",
+    "finished" : "valmis",
     "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
     "Move or copy" : "Siirrä tai kopioi",
     "Download" : "Lataa",
     "Delete" : "Poista",
     "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
     "Terms of service" : "Käyttöehdot",
+    "Show list view" : "Näytä listanäkymä",
+    "Show grid view" : "Näytä ruudukkonäkymä",
     "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
     "Invalid server URL" : "Virheellinen palvelimen URL",
     "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
     "No expiration date set" : "Ei vanhenemispäivää asetettu",
     "Shared by" : "Jakanut",
     "File shares" : "Tiedostojaot",
-    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
+    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
     "Downloaded by {email}" : "Ladannut {email}",
     "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
     "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
@@ -48,10 +52,11 @@ OC.L10N.register(
     "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
     "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
     "Share for group {group} expired" : "Jako ryhmälle {group} vanhentui",
-    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
-    "You removed group {group} from {file}" : "Poistit ryhmän {group} kohteen {file} käyttöoikeudet",
+    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
+    "You removed group {group} from {file}" : "Poistit ryhmän {group} tiedostosta {file}",
     "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
     "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
+    "Share for file {file} with group {group} expired" : "Tiedoston {file} jako ryhmän {group} kanssa on päättynyt",
     "Shared as public link" : "Jaettu julkisella linkillä",
     "Removed public link" : "Julkinen linkki poistettu",
     "Public link expired" : "Julkinen linkki vanhentui",
@@ -73,6 +78,7 @@ OC.L10N.register(
     "Shared with {user}" : "Jaettu käyttäjälle {user}",
     "Removed share for {user}" : "Poisti jaon käyttäjälle {user}",
     "You removed yourself" : "Poistit itsesi",
+    "{actor} removed themselves" : "{actor} poisti itsensä",
     "{actor} shared with {user}" : "{actor} jakoi käyttäjälle {user}",
     "{actor} removed share for {user}" : "{actor} poisti jaon käyttäjälle {user}",
     "Shared by {actor}" : "Jakanut {actor}",
@@ -82,53 +88,76 @@ OC.L10N.register(
     "You shared {file} with {user}" : "Jaoit kohteen {file} käyttäjälle {user}",
     "You removed {user} from {file}" : "Poistit käyttäjän {user} kohteen {file} käyttöoikeudet",
     "You removed yourself from {file}" : "Poistit itsesi tiedostosta {file}",
+    "{actor} removed themselves from {file}" : "{actor} poisti itsensä tiedostosta {file}",
     "{actor} shared {file} with {user}" : "{actor} jakoi kohteen {file} käyttäjälle {user}",
     "{actor} removed {user} from {file}" : "{actor} poisti käyttäjän {user} kohteen {file} käyttöoikeudet",
     "{actor} shared {file} with you" : "{actor} jakoi kohteen {file} kanssasi",
     "{actor} removed you from the share named {file}" : "{actor} poisti sinut jaosta nimeltä {file}",
+    "Share for file {file} with {user} expired" : "Tiedoston {file} jako käyttäjän {user} kanssa on päättynyt",
     "Share for file {file} expired" : "Tiedoston {file} jako vanhentui",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
     "Files" : "Tiedostot",
     "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
-    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
-    "Could not delete share" : "Jaon poistaminen epäonnistui",
+    "Shared link" : "Jaettu linkki",
+    "Wrong share ID, share does not exist" : "Väärä jaon ID, jakoa ei ole olemassa",
+    "Could not delete share" : "Jaon poistaminen epäonnistui",
     "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
-    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
+    "Wrong path, file/folder does not exist" : "Väärä polku, tiedostoa/kansiota ei ole olemassa",
     "Could not create share" : "Jaon luominen epäonnistui",
-    "invalid permissions" : "vialliset oikeudet",
+    "Invalid permissions" : "Virheelliset käyttöoikeudet",
     "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
     "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
     "Please specify a valid group" : "Määritä kelvollinen ryhmä",
     "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
     "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
     "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
+    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
+    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
     "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
     "Please specify a valid circle" : "Määritä kelvollinen piiri",
+    "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
     "Unknown share type" : "Tuntematon jaon tyyppi",
     "Not a directory" : "Ei hakemisto",
+    "Could not lock node" : "Solmua ei voitu lukita",
     "Could not lock path" : "Polun lukitseminen ei onnistunut",
     "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
-    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
-    "shared by %s" : "%s jakama",
+    "Share must at least have READ or CREATE permissions" : "Jaolla tulee olla vähintään luku- tai kirjoitusoikeus",
+    "shared by %s" : "käyttäjän %s jakama",
     "Download all files" : "Lataa kaikki tiedostot",
     "Direct link" : "Suora linkki",
-    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
+    "Add to your %s" : "Lisää %siisi",
     "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
     "File sharing" : "Tiedostonjako",
     "Share will expire tomorrow" : "Jako vanhenee huomenna",
-    "One or more of your shares will expire tomorrow" : "Yksi tai useampi jaoistasi vanhenee huomenna",
+    "Your share of {node} will expire tomorrow" : "Jakosi {node} vanhenee huomenna",
+    "You received {share} as a share by {user}" : "Vastaanotit jaon {share} käyttäjältä {user}",
+    "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
     "Accept" : "Hyväksy",
     "Reject" : "Hylkää",
     "Sharing" : "Jakaminen",
     "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
+    "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
+    "Reset" : "Palauta",
+    "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
+    "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
+    "Invalid path selected" : "Virheellinen polku valittu",
+    "Unknown error" : "Tuntematon virhe",
     "Allow editing" : "Salli muokkaus",
+    "Read only" : "Vain luku",
+    "Allow upload and editing" : "Salli lähetys ja muokkaus",
+    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
+    "Custom permissions" : "Mukautetut oikeudet",
+    "Read" : "Lue",
+    "Upload" : "Lähetä",
+    "Edit" : "Muokkaa",
     "Allow creating" : "Salli luominen",
     "Allow deleting" : "Salli poistaminen",
     "Allow resharing" : "Salli uudelleenjakaminen",
     "Expiration date enforced" : "Vanhenemispäivä pakotettu",
     "Set expiration date" : "Aseta vanhenemispäivä",
+    "Enter a date" : "Syötä päivämäärä",
     "Note to recipient" : "Huomio vastaanottajalle",
     "Unshare" : "Lopeta jakaminen",
     "group" : "ryhmä",
@@ -136,62 +165,103 @@ OC.L10N.register(
     "remote" : "etä",
     "remote group" : "etäryhmä",
     "guest" : "vieras",
+    "Shared with the group {user} by {owner}" : "Jaettu ryhmän {user} kanssa käyttäjältä {owner}",
+    "Shared with the conversation {user} by {owner}" : "Jaettu keskustelun {user} kanssa käyttäjältä {owner}",
+    "Shared with {user} by {owner}" : "{owner} jakoi käyttäjälle {user}",
+    "Allow download" : "Salli lataus",
+    "Added by {initiator}" : "Lisäyksen tehnyt {initiator}",
+    "Via “{folder}”" : "“{folder}” kautta",
     "Internal link" : "Sisäinen linkki",
-    "Link copied" : "Linkki kopioitu",
     "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
-    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
     "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
+    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
+    "Link copied" : "Linkki kopioitu",
     "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
     "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
     "Password protection" : "Salasanasuojaus",
     "Enter a password" : "Syötä salasana",
     "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
+    "Create share" : "Luo jako",
     "Cancel" : "Peruuta",
-    "Read only" : "Vain luku",
-    "Allow upload and editing" : "Salli lähetys ja muokkaus",
-    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
+    "Share label" : "Jaon nimi",
     "Hide download" : "Piilota lataus",
     "Password protect" : "Suojaa salasanalla",
+    "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
+    "Password expired" : "Salasana vanheni",
+    "Video verification" : "Videovarmistus",
+    "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
     "Add another link" : "Lisää toinen linkki",
     "Create a new share link" : "Luo uusi jakolinkki",
+    "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
+    "Mail share ({label})" : "Sähköpostijako ({label})",
+    "Share link ({label})" : "Jaa linkki ({label})",
+    "Share link ({index})" : "Jaa linkki ({index})",
     "Share link" : "Jaa linkki",
+    "Actions for \"{title}\"" : "Toiminnot kohteelle \"{title}\"",
+    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
+    "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
+    "Link share created" : "Linkkijako luotu",
+    "Error while creating the share" : "Virhe jakoa luotaessa",
+    "Search for share recipients" : "Etsi jaon vastaanottajia",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
-    "Resharing is not allowed" : "Uudellenjako ei ole salluttu",
+    "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
+    "Name or email …" : "Nimi tai sähköposti...",
+    "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
     "Searching …" : "Haetaan…",
     "No elements found." : "Elementtejä ei löytynyt.",
     "Search globally" : "Hae globaalisti",
+    "Guest" : "Vieras",
+    "Group" : "Ryhmä",
+    "Email" : "Sähköposti",
+    "Circle" : "Piiri",
+    "Talk conversation" : "Talk-keskustelu",
+    "Deck board" : "Deck-taulu",
     "on {server}" : "palvelimella {server}",
+    "Others with access" : "Muut, joilla on käyttöoikeus",
+    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
+    "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
+    "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
+    "Unable to load the shares list" : "Jakolistan haku epäonnistui",
     "Expires {relativetime}" : "Vanhenee {relativetime}",
     "this share just expired." : "tämä jako vanheni juuri.",
+    "Shared with you by {owner}" : "{owner} jakoi tämän kanssasi",
     "Link to a file" : "Linkki tiedostoon",
+    "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
     "Error creating the share" : "Virhe jakoa luotaessa",
+    "Error updating the share: {errorMessage}" : "Virhe päivittäessä jakoa: {errorMessage}",
     "Error updating the share" : "Virhe jakoa päivittäessä",
+    "Share {propertyName} saved" : "Jako {propertyName} tallennettu",
     "Shared" : "Jaettu",
     "Share" : "Jaa",
     "Shared with" : "Jaettu",
+    "Password created successfully" : "Salasana luotu onnistuneesti",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
-    "Shared with you by {owner}" : "Jaettu kanssasi käyttäjältä {owner}",
+    "Shared with you and {circle} by {owner}" : "{owner} on jakanut tämän sinun ja piirin {circle} kanssa",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} on jakanut tämän sinun ja keskustelun {conversation} kanssa",
+    "Shared with you in a conversation by {owner}" : "{owner} jakoi tämän kanssasi keskustelussa",
     "No entries found in this folder" : "Ei kohteita tässä kansiossa",
     "Name" : "Nimi",
     "Share time" : "Jakamisen ajankohta",
     "Expiration date" : "Vanhenemispäivä",
-    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
+    "Sorry, this link does not seem to work anymore." : "Valitettavasti tämä linkki ei vaikuta enää toimivan.",
     "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
     "the item was removed" : "kohde poistettiin",
     "the link expired" : "linkki vanheni",
     "sharing is disabled" : "jakaminen on poistettu käytöstä",
     "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
     "Share note" : "Jaa muistiinpano",
-    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
-    "Download %s" : "Lataa %s",
     "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
     "Note" : "Huomio",
     "Select or drop files" : "Valitse tai pudota tiedostoja",
     "Uploading files" : "Lähetetään tiedostoja",
     "Uploaded files:" : "Lähetetyt tiedostot:",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
-    "Name or email address …" : "Nimi tai sähköpostiosoite…",
-    "Name …" : "Nimi…",
-    "Uploading files…" : "Lähetetään tiedostoja…"
+    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
+    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
+    "One or more of your shares will expire tomorrow" : "Yksi tai useampi jaoistasi vanhenee huomenna",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
+    "Toggle grid view" : "Ruudukkonäkymä päälle/pois"
 },
 "nplurals=2; plural=(n != 1);");
