@@ -1,12 +1,14 @@
 OC.L10N.register(
     "firstrunwizard",
     {
-    "Copy to clipboard" : "انسخه إلى الحافظة",
     "Copied!" : "تم نسخه!",
     "Not supported!" : "غير مدعوم!",
     "Press ⌘-C to copy." : "إضغط ⌘-C للنسخ",
     "Press Ctrl-C to copy." : "إضغط Ctrl-C للنسخ.",
     "First run wizard" : "دليل التشغيل لأول مرة",
+    "Schedule work & meetings, synced with all your devices." : "قم بجدولة العمل والإجتماعات ، بالتزامن مع جميع أجهزتك.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "احتفظ بزملائك وأصدقائك في مكان واحد دون تسريب معلوماتهم الخاصة.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "تطبيق بريد إلكتروني بسيط متوافق بشكل ممتاز مع الملفات وجهات الاتصال والتقويم.",
     "About" : "عن",
     "Communication with Nextcloud Talk" : "التواصل مع Nextcloud Talk",
     "Get the apps to sync your files" : "احصل على التطبيقات لمزامنة ملفاتك",
@@ -17,23 +19,20 @@ OC.L10N.register(
     "Connect your contacts" : "قم بريط قائمة مراسليك",
     "Access files via WebDAV" : "دخول الملفات باستخدام WebDAV",
     "Get help" : "الحصول على مساعدة",
+    "Start contributing" : "ابدأ في المساهمة",
+    "Become part of the Community" : "اصبح عضوا في المجتمع",
     "Get more information" : "احصل على المزيد من المعلومات",
     "User manual" : "دليل المستخدم",
     "Admin manual" : "دليل المدير",
     "Developer manual" : "دليل المُطوّر",
     "the Nextcloud forums" : "منتديات Nextcloud",
-    "the Nextcloud IRC chat channel on freenode.net" : "قناة IRC للدردشة الخاصة بـ Nextcloud على freenode.net",
-    "Start contributing" : "ابدأ في المساهمة",
-    "Become part of the Community" : "اصبح عضوا في المجتمع",
     "A safe home for all your data" : "المكان الآمن لكافة بياناتكم",
     "Host your data and files where you decide" : "استضف بياناتك في المكان الذي تقرره أنت",
-    "100%% Open Source & community-focused" : "منصة مفتوحة المصدر 100%% موجهة للمجتمع",
     "Learn more about %s" : "تعلم المزيد عن %s",
     "Connect other apps to %s" : "قم بربط تطبيقات أخرى مع %s",
     "Server address" : "عنوان الخادم",
     "Copy link" : "انسخ الرابط",
-    "Start using Nextcloud" : "اشرع في استخدام ناكست كلاود",
-    "Browse the app store" : "استكشف متجر التطبيقات",
-    "Android app" : "تطبيق أندرويد"
+    "Copy to clipboard" : "انسخه إلى الحافظة",
+    "the Nextcloud IRC chat channel on freenode.net" : "قناة IRC للدردشة الخاصة بـ Nextcloud على freenode.net"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
