@@ -1,14 +1,14 @@
 OC.L10N.register(
     "firstrunwizard",
     {
-    "Copy to clipboard" : "Kopioi leikepöydälle",
     "Copied!" : "Kopioitu!",
     "Not supported!" : "Ei tuettu!",
     "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
     "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
     "First run wizard" : "Ensimmäisen käyttökerran avustaja",
-    "Add your profile information! For example your email is needed to reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan salasanan palauttamiseen.",
-    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
+    "Add your profile information! For example your email is needed to receive notifications." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen.",
+    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan ilmoitusten vastaanottamiseen ja salasanan palauttamiseen.",
+    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
     "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
     "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
     "App recommendation: Nextcloud Calendar" : "Sovellussuositus: Nextcloud-kalenteri",
@@ -21,35 +21,43 @@ OC.L10N.register(
     "Sync tasks from various devices with your Nextcloud and edit them online." : "Synkronoit tehtäviä eri laitteista Nextcloudiisi ja muokkaa niitä netissä.",
     "App recommendation: Deck" : "Sovellussuositus: Pakka",
     "Kanban style organization for personal planning and team projects." : "Kanban-tyylistä organisointia henkilökohtaiseen suunnitteluun ja ryhmäprojekteihin.",
-    "App recommendation: Notes" : "Sovellussuositus: Muistiinpanot",
-    "Distraction-free notes and writing." : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
-    "App recommendation: Social" : "Sovellussuositus: Sosiaalinen",
+    "App recommendation: Forms" : "Sovellussuositus: Lomakkeet",
+    "Simple surveys and questionnaires, self-hosted" : "Helppoja ja yksinkertaisia kyselyitä omalla palvelimella",
+    "App recommendation: Recognize" : "Sovellussuositus: Tunnista",
+    "Smart media tagging for Nextcloud" : "Median älykästä merkitsemistä tunnisteilla Nextcloudille",
     "App recommendation: Group folders" : "Sovellussuositus: Ryhmäkansiot",
     "Admin-configured folders shared by everyone in a group." : "Ylläpitäjän määrittämät kansiot jaettuina kaikille ryhmän jäsenille.",
     "About" : "Tietoja",
     "A welcome and introduction wizard for Nextcloud" : "Nextcloudin ensimmäisen käyttökerran avustaja",
-    "Start using Nextcloud" : "Aloita Nextcloudin käyttäminen",
+    "Start using {cloudName}" : "Aloita pilven {cloudName} käyttäminen",
+    "Welcome to {cloudName}!" : "Tervetuloa pilveen {cloudName}!",
     "Extend your cloud" : "Laajenna pilveäsi",
-    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Löydä yli 100 eri sovellusta Nextcloud-sovelluskaupasta pilvesi muokkaamiseksi:",
+    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Löydä yli 100 eri sovellusta Nextcloud-sovelluskaupasta pilvesi muokkaamiseksi:",
     "Groupware apps like Calendar, Contacts, Mail" : "Työryhmäohjelmistot kuten kalenteri, yhteystiedot ja sähköposti",
     "Communication with Nextcloud Talk" : "Yhteydenpito Nextcloud Talkilla",
     "Collaboration apps for document editing" : "Yhteistyösovellukset asiakirjojen muokkaukseen",
     "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
     "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Paljon muuta kuten musiikkisoitin, salasanahallinta, kanban-sovellus, lataushallinta ja markdown-muokkain",
-    "Browse the app store" : "Selaa sovelluskauppaa",
+    "Browse the App Store" : "Selaa sovelluskauppaa",
     "Stay in sync" : "Pysy synkronoituna",
     "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
     "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suosituimmille alustoille ilman kustannuksia!",
     "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
     "Desktop client" : "Työpöytäsovellus",
-    "Android app" : "Android-sovellus",
+    "Android app on Google Play Store" : "Android-sovellus Google Play Storessa",
+    "Android app on F-Droid" : "Android-sovellus F-Droidissa",
     "iOS app" : "iOS-sovellus",
-    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi %siin",
+    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi pilveen %s",
     "Connect your calendar" : "Yhdistä kalenteriisi",
     "Connect your contacts" : "Yhdistä yhteystietoihisi",
     "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
     "Download macOS/iOS configuration profile" : "Lataa macOS-/iOS-asetusprofiili",
     "Get help" : "Saa apua",
+    "Start contributing" : "Anna oma panoksesi",
+    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Haluatko tietyn parannuksen Nextcloudiin? Löysitkö ongelman? Haluatko kääntää, mainostaa tai dokumentoida Nextcloudia?",
+    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
+    "Enterprise support" : "Yritystuki",
+    "Learn more about Nextcloud Enterprise" : "Lue lisää Nextcloudin Enterprise-versiosta",
     "Get more information" : "Hanki lisätietoja",
     "The Nextcloud documentation for home users:" : "Nextcloud-ohjeet kotikäyttäjille:",
     "User manual" : "Käyttäjän ohje",
@@ -57,28 +65,25 @@ OC.L10N.register(
     "Developer manual" : "Kehittäjän ohje",
     "You can also ask for help in our community support channels:" : "Voit kysyä apua myös yhteisön tukikanavilta:",
     "the Nextcloud forums" : "Nextcloud-keskustelualueet",
-    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloudin IRC-kanava freenode.net-verkossa",
-    "Start contributing" : "Anna oma panoksesi",
-    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Haluatko tietyn parannuksen Nextcloudiin? Löysitkö ongelman? Haluatko kääntää, mainostaa tai dokumentoida Nextcloudia?",
-    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
-    "Enterprise support" : "Yritystuki",
-    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Jos käytät Nextcloudia kriittisessä tuotantoympäristössä, ja palvelussa on suuri määrä käyttäjiä sekä tietoa, saatat tarvita varmuuden tuen saamisesta. Nextcloud-teknologiasta vastaavat asiantuntijat tarjoavat yritystasotilauksen pohjalta tukea sähköpostitse ja puhelimitse.",
-    "Get enterprise support" : "Hanki yritystason tukea",
     "A safe home for all your data" : "Turvallinen koti kaikille tiedoillesi",
-    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud asettaa tietosi sinun hallintaasi. Talleta asiakirjat, kalenteri, yhteystiedot ja kuvat organisaatiosi tarjoamalle palvelimelle, kotipalvelimellesi, Nextcloudin yhteistyökumppanien palvelimelle tai luottamaasi palvelinkeskukseen.",
+    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud asettaa tietosi sinun hallintaasi. Talleta asiakirjat, kalenteri, yhteystiedot ja kuvat organisaatiosi tarjoamalle palvelimelle, kotipalvelimellesi, Nextcloudin yhteistyökumppanien palvelimille tai luottamaasi palvelinkeskukseen.",
     "Host your data and files where you decide" : "Säilytä tietosi ja tiedostosi missä itse haluat",
-    "Open Standards and Interoperability" : "Avoimet standardit ja yhteentoimivuus",
-    "100%% Open Source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
+    "Open standards and interoperability" : "Avoimet standardit ja yhteentoimivuus",
+    "100%% open source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
     "Learn more about %s" : "Lisätietoja - %s",
-    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s mahdollistaa pääsyn tiedostoihisi missä hyvänsä oletkin. Hellpokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suurimmille alustoille veloituksetta.",
+    "This Nextcloud is on version %s" : "Tämä Nextcloud on versiossa %s",
+    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s mahdollistaa pääsyn tiedostoihisi missä hyvänsä oletkin. Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suurimmille alustoille veloituksetta.",
     "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Määritä synkronointi käyttäen <a href=\"%s\">sovelluskohtaisia salasanoja</a>. Näin voit kumota käyttöoikeuden, jos satut esimerkiksi kadottamaan tietyn laitteesi",
-    "Connect other apps to %s" : "Yhdistä muita sovelluksia %siin",
-    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Synkronointisovellusten lisäksi voit yhdistää minkä tahansa WebDAV-, CalDAV- ja CardDAV-yhteyskäytäntöjä tukevan ohjelmiston %siin",
+    "Connect other apps to %s" : "Yhdistä muita sovelluksia pilveen %s",
+    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Synkronointisovellusten lisäksi voit yhdistää minkä tahansa WebDAV-, CalDAV- ja CardDAV-yhteyskäytäntöjä tukevan ohjelmiston pilveen %s",
     "Server address" : "Palvelimen osoite",
     "Use this link to connect your apps and desktop client to this server:" : "Käytä tätä linkkiä yhdistääksesi sovellukset ja työpöytäsovelluksen tähän palvelimeen:",
     "Copy link" : "Kopioi linkki",
-    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Paljon muuta kuten musiikkisoitin, salasanahallinta, kanban-sovellus, lataushallinta ja markdown-muokkain",
-    "Previous" : "Edellinen",
-    "Next" : "Seuraava"
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "App recommendation: Notes" : "Sovellussuositus: Muistiinpanot",
+    "Distraction-free notes and writing." : "Häiriötöntä muistiinpanojen ottamista ja kirjoittamista",
+    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Jos käytät Nextcloudia kriittisessä tuotantoympäristössä, ja palvelussa on suuri määrä käyttäjiä sekä tietoa, saatat tarvita varmuuden tuen saamisesta. Nextcloud-teknologiasta vastaavat asiantuntijat tarjoavat yritystasotilauksen pohjalta tukea sähköpostitse ja puhelimitse.",
+    "Get enterprise support" : "Hanki yritystason tukea",
+    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloudin IRC-kanava freenode.net-verkossa"
 },
 "nplurals=2; plural=(n != 1);");
