@@ -4,9 +4,10 @@ OC.L10N.register(
     "Privacy" : "Integritet",
     "-" : "-",
     "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Sekretesscentret visar var din data lagras och vem som kan komma åt den, antingen för att du delade med dem eller för att de är administratörer.",
-    "Remove external admin" : "Ta bort extern administratör",
+    "Remove external {propertyName} admin" : "Ta bort extern {propertyName} admin",
     "Add external admin" : "Lägg till extern administratör",
     "Name of external admin" : "Namn på extern administratör",
+    "Adapt encryption" : "Anpassa kryptering",
     "This server is using full-disk-encryption." : "Servern använder fullständig disk-kryptering.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Dina filer på externa lagringsutrymmen kan krypteras med {linkopen}serverkryptering ↗{linkclose} med en huvudnyckel baserad på deras konfiguration.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Dina filer på externa lagringsutrymmen kan krypteras med {linkopen}serverkryptering ↗{linkclose} med en individuell nyckel baserad på deras konfiguration.",
@@ -286,6 +287,7 @@ OC.L10N.register(
     "Privacy policy" : "Integritetspolicy",
     "Read the privacy policy." : "Läs integritetspolicy.",
     "Encryption" : "Kryptering",
+    "Remove external admin" : "Ta bort extern administratör",
     "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Din hemkatalog är krypterad med {linkopen}serverkryptering ↗{linkclose} med en huvudnyckel.",
     "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Din hemkatalog är krypterad med {linkopen}serverkryptering ↗{linkclose} med en individuell nyckel per användare."
 },
