@@ -1,12 +1,14 @@
 OC.L10N.register(
     "recommendations",
     {
+    "Recommended files" : "Fichiers recommandés",
     "Recently commented" : "Commentés récemment",
-    "Recently edited" : "Modifiés récemment",
+    "Recently edited" : "Modifié récemment",
     "Recently shared" : "Partagés récemment",
     "Recommendations" : "Recommandations",
     "Shows recommended files" : "Affiche les fichiers recommandés",
     "Shows recommended files for quick access of files and folders with recent activity" : "Affiche les fichiers recommandés pour un accès rapide aux fichiers et dossiers ayant une activité récente",
+    "No recommendations yet" : "Aucune recommandation pour l'instant",
     "Show recommendations" : "Afficher les recommandations"
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
