@@ -106,6 +106,7 @@
 					self._onScopeChanged(field, scope);
 				});
 				$icon.append(scopeMenu.$el);
+				$icon.attr('aria-expanded', 'false');
 				$icon.on('click', _.bind(scopeMenu.show, scopeMenu));
 				$icon.on('keydown', function(e) {
 					if (e.keyCode === 32) {
@@ -128,7 +129,12 @@
 			_.each(this._inputFields, function(field) {
 				if (
 					field === 'avatar' ||
-					field === 'email'
+					field === 'email' ||
+					field === 'displayname' ||
+					field === 'twitter' ||
+					field === 'address' ||
+					field === 'website' ||
+					field === 'phone'
 				) {
 					return;
 				}
