@@ -19,6 +19,7 @@ OC.L10N.register(
     "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
     "Use current version" : "Käytä nykyistä versiota",
     "Use the saved version" : "Käytä tallennettua versiota",
+    "Failed to load file" : "Tiedoston lataaminen epäonnistui",
     "Document idle for {timeout} minutes, click to continue editing" : "Dokumentti on ollut käyttämättömänä {timeout} minuuttia, klikkaa jatkaaksesi muokkausta",
     "Reconnect" : "Yhdistä uudelleen",
     "The document has been changed outside of the editor. The changes cannot be applied." : "Dokumenttia on muutettu editorin ulkopuolella. Muutoksia ei voida tallentaa.",
@@ -34,11 +35,10 @@ OC.L10N.register(
     "Author colors are only shown until everyone has closed the document." : "Tekijöiden värit näytetään siihen asti, kunnes kaikki ovat sulkeneet asiakirjan.",
     "Active people" : "Aktiiviset ihmiset",
     "Last saved" : "Viimeksi tallennettu",
+    "Offline" : "Poissa",
     "Saving …" : "Tallennetaan...",
     "Saved" : "Tallennettu",
-    "Last saved {lastSaved}" : "Viimeksi tallennettu {lastSaved}",
     "Unsaved changes" : "Tallentamattomia muutoksia",
-    "No emoji found" : "Emojia ei löydy",
     "Formatting help" : "Muotoiluohje",
     "Speed up your writing with simple shortcuts." : "Nopeuta kirjoittamista pikanäppäimillä.",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "Kirjoita Markdown-syntaksia tai käytä alla olevia pikanäppäimiä.",
@@ -46,6 +46,7 @@ OC.L10N.register(
     "Style" : "Tyyli",
     "Syntax" : "Syntaksi",
     "Keyboard shortcuts" : "Pikanäppäimet",
+    "New paragraph" : "Uusi kappale",
     "Shift" : "Siirrä",
     "Bold" : "Lihavoitu",
     "Bold text" : "Lihavoitu teksti",
@@ -67,17 +68,21 @@ OC.L10N.register(
     "Quoted text" : "Lainattu teksti",
     "Code block" : "Koodilohko",
     "Some code" : "Koodia",
-    "No user found" : "Käyttäjää ei löytynyt",
     "Upload from computer" : "Lähetä tietokoneelta",
     "Insert from Files" : "Syötä Tiedostot-sovelluksesta",
     "Remove link" : "Poista linkki",
     "Link to file or folder" : "Linkki tiedostoon tai kansioon",
     "Link to website" : "Linkki verkkosivulle",
     "Update link" : "Päivitä linkki",
+    "Open link picker" : "Avaa linkkivalitsin",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
     "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
     "_%n char_::_%n chars_" : ["%n merkki","%n merkkiä"],
     "Formatting menu bar" : "Muotoiluvalikko",
+    "No emoji found" : "Emojia ei löydy",
+    "No command found" : "Komentoa ei löytynyt",
+    "No user found" : "Käyttäjää ei löytynyt",
+    "No suggestion found" : "Ehdotusta ei löytynyt",
     "Link to this section" : "Linkki tähän osioon",
     "Delete this attachment" : "Poista tämä liite",
     "Delete this image" : "Poista tämä kuva",
@@ -91,7 +96,6 @@ OC.L10N.register(
     "Delete this column" : "Poista tämä sarake",
     "Delete this table" : "Poista tämä taulu",
     "Show rich workspaces" : "Näytä rikastetut työtilat",
-    "Add notes, lists or links …" : "Lisää muistiinpanoja, listoja tai linkkejä...",
     "Undo" : "Kumoa",
     "Redo" : "Tee uudelleen",
     "Headings" : "Otsikot",
@@ -108,7 +112,10 @@ OC.L10N.register(
     "Insert attachment" : "Lisää liite",
     "Command" : "Komento",
     "Control" : "Hallinta",
+    "Add notes, lists or links …" : "Lisää muistiinpanoja, listoja tai linkkejä...",
     "Edit" : "Muokkaa",
+    "Add description" : "Lisää kuvaus",
+    "Last saved {lastSaved}" : "Viimeksi tallennettu {lastSaved}",
     "Image file format not supported" : "Kuvan tiedostomuoto ei ole tuettu",
     "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
     "Insert an image" : "Lisää kuva",
