@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "لا يمكن إكمال عملية تسجيل الدخول",
     "Your login token is invalid or has expired" : "معلومات الجلسة غير صالحة أو منتهية",
     "Login" : "الدخول",
+    "Please try again" : "يرجى إعادة المحاولة",
     "Password reset is disabled" : "تم تعطيل إعادة تعيين كلمة المرور",
     "Could not reset password because the token is expired" : "لا يمكن إعادة تعيين كلمة المرور بسبب انتهاء صلاحية الجلسة.",
     "Could not reset password because the token is invalid" : "لا يمكن إعادة تعيين كلمة المرور بسبب خطأ في تكوين الجلسة",
@@ -39,7 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "تم ازالة البعض من مشاركة الروابط الخاصة بك.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "نظرا لسبب آمني تم ازالة البعض من روابط المشاركة الخاصة بك. يرجى مراجعة الرابط التالي لمزيد من التفاصيل.",
     "The user limit of this instance is reached." : "وصل المستخدم إلى الحد من هذه النسخة",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "أدخل مفتاح اشتراكك لزيادة حد المستخدم. لمزيد من المعلومات حول مشروع نكست كلاود، راجع موقعنا على الويب.",
+    "Learn more ↗" : "تعلم المزيد ↗",
     "Preparing update" : "جارٍ تهيئة التحديث",
     "[%d / %d]: %s" : "[%d/%d]: %s",
     "Repair step:" : "خطوة صيانة:",
@@ -129,7 +130,9 @@ OC.L10N.register(
     "Please contact your administrator." : "يرجى التواصل مع مسؤول النظام.",
     "An internal error occurred." : "حدث خطأ داخلي.",
     "Please try again or contact your administrator." : "حاول مجددا أو تواصل مع مسؤول النظام.",
+    "Account name or email" : "اسم الحساب أو البريد الالكتروني",
     "Password" : "كلمة المرور",
+    "Log in to {productName}" : "الولوج إلى {productName}",
     "Wrong username or password." : "اسم المستخدم أو كلمة المرور خاطئة.",
     "User disabled" : "المستخدم معطّل",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "لقد اكتشفنا عدة محاولات تسجيل دخول غير صالحة من عنوان IP الخاص بك. لذلك تم تقييد تسجيل الدخول التالي الخاص بك حتى 30 ثانية.",
@@ -180,6 +183,7 @@ OC.L10N.register(
     "Search" : "البحث",
     "An error occurred while searching for {type}" : "حدث خطأ أثناء البحث عن {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength}  أو أكثر للبحث"],
+    "Settings menu" : "قائمة الإعدادات",
     "Search {types} …" : "بحث {types} …",
     "Settings" : "الإعدادات",
     "Could not load your contacts" : "تعذر تحميل جهات الإتصال",
@@ -220,6 +224,7 @@ OC.L10N.register(
     "(all selected)" : "(إختيار الكل)",
     "({count} selected)" : "({count} تم تحديد)",
     "Error loading file exists template" : "خطأ في تحميل القالب الحالي",
+    "Show list view" : "اظهر معاينات الروابط",
     "Pending" : "معلّق",
     "Copy to {folder}" : "أنسخ إلى {folder}",
     "Move to {folder}" : "النقل إلى {folder}",
@@ -264,8 +269,6 @@ OC.L10N.register(
     "Access forbidden" : "الوصول محظور",
     "The profile does not exist." : "الملف الشخصي غير موجود.",
     "Back to %s" : "العودة إلى %s",
-    "File not found" : "لم يتم العثور على الملف",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "لا يمكن العثور على المستند، ربما المشاركة محذوفه او منتهيه؟",
     "Too many requests" : "الطلبات أقصى من الحد المسموح",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "يوجد طلبات أقصى من الحد المسموح به في الشبكة. أعد المحاولة أو اتصل بمسؤول النظام.",
     "Error" : "خطأ",
@@ -315,8 +318,6 @@ OC.L10N.register(
     "Skip to main content" : "تخطّيه وانتقل إلى المحتوى الرئيسي",
     "Skip to navigation of app" : "تجاهل التنقل في التطبيق",
     "Get your own free account" : "احصل على حساب لك بالمجان",
-    "Contacts" : "جهات الإتصال",
-    "Contacts menu" : "قائمة جهات الإتصال",
     "Confirm your password" : "تأكيد كلمتك السرية",
     "Connect to your account" : "الاتصال بحسابك",
     "Please log in before granting %1$s access to your %2$s account." : "يرجى تسجيل الدخول قبل الحصول على اذن %1$s في حسابك %2$s.",
@@ -366,25 +367,19 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "هذا %s في وضع الصيانة، قد يستغرق ذلك بعض الوقت.",
     "This page will refresh itself when the instance is available again." : "سوف يتم تحديث الصفحة في حين الخادم جاهز للاستخدام مجددا.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "تواصل مع مسؤول النظام اذا استمرت هذه الرسالة بالظهور دائما أو بشكل مفاجئ.",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "إصدار المجتمع هذا من Nextcloud غير مدعوم والإشعارات الفورية غير متاحة.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: تحديث الجدول %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "هذا الخادم ليس لديه اتصال إنترنت يعمل: لا يمكن الوصول إلى نقاط نهاية متعددة. هذا يعني أن بعض الميزات مثل تركيب وحدة تخزين خارجية أو إخطارات حول التحديثات أو تثبيت تطبيقات الطرف الثالث لن تعمل. قد لا يعمل الوصول إلى الملفات عن بُعد وإرسال رسائل البريد الإلكتروني الخاصة تنبيه أيضًا. قم بتأسيس اتصال من هذا الخادم بالإنترنت للاستمتاع بجميع الميزات.",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "نكست كلاود 20 هو آخر اصدار يدعم PHP 7.2. نكست كلاود 21 يتطلب على الاقل PHP 7.3.",
-    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "لم يتم تحميل وحدة PHP OPcache. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">للحصول على أداء أفضل يوصى</a> بتحميله في تثبيت نسخة PHP الخاصة بك.",
-    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "لم يتم تكوين PHP OPcache بشكل صحيح.{linkstart} للحصول على أداء أفضل يوصى{linkend} باستخدام الإعدادات التالية في ملف <code>php.ini</code>:",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "تفتقد بعض الأعمدة في قاعدة البيانات إلى تحويل كبير إلى عدد صحيح. نظرًا لحقيقة أن تغيير أنواع الأعمدة في الجداول الكبيرة قد يستغرق بعض الوقت لم يتم تغييرها تلقائيًا. من خلال تشغيل \"occ db: convert-filecache-bigint\" يمكن تطبيق هذه التغييرات المعلقة يدويًا. يجب إجراء هذه العملية أثناء الحالة غير متصل. لمزيد من التفاصيل ، اقرأ {linkstart} صفحة التوثيق حول هذا الموضوع ↗ {linkend}.",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "لدمج إلى قاعدة بيانات أخرى ، استخدم أداة سطر الأوامر: 'occ db: convert-type' ، أو راجع {linkstart} التعليمات ↗{linkend}.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "ربما يمكن الوصول إلى دليل البيانات والملفات الخاصة بك من الإنترنت. ملف htaccess لا يعمل. يوصى بشدة بتكوين خادم الويب الخاص بك بحيث لا يمكن الوصول إلى دليل البيانات ، أو نقل دليل البيانات خارج جذر مستند خادم الويب.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "لا يحتوي رأس HTTP \"{header}\" على \"{expected}\". يعد هذا خطرًا محتملاً على الأمان أو الخصوصية ، حيث يوصى بضبط هذا الإعداد وفقًا لذلك.",
     "Collaboratively edit office documents." : "تحرير مستندات المكتب بشكل تعاوني.",
     "Local document editing back-end used by the Collabora Online app." : "خلفية تحرير المستندات المحلية المستخدمة بواسطة تطبيق Collabora Online.",
     "restricted" : "مُقيَّد",
     "invisible" : "مخفي",
+    "File not found" : "لم يتم العثور على الملف",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "لا يمكن العثور على المستند، ربما المشاركة محذوفه او منتهيه؟",
     "More" : "المزيد",
     "More apps menu" : "المزيد من قائمة التطبيقات",
-    "Settings menu" : "قائمة الإعدادات",
-    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى.",
-    "Setup two-factor authentication" : "تعيين المصادقة بخطوتين",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "إصدار المجتمع هذا من Nextcloud غير مدعوم والإشعارات الفورية غير متاحة.",
-    "You haven't added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن"
+    "Contacts" : "جهات الإتصال",
+    "Contacts menu" : "قائمة جهات الإتصال",
+    "Setup two-factor authentication" : "تعيين المصادقة بخطوتين"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
