@@ -9,6 +9,11 @@ OC.L10N.register(
     "Settings" : "Podešavanje",
     "Log out" : "Odjava",
     "Users" : "Korisnici",
+    "Email" : "E-pošta",
+    "Phone" : "Telefon",
+    "Website" : "Web-prezentacija",
+    "Address" : "Adresa",
+    "Profile picture" : "Slika profila",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Korištenje na vlastiti rizik!",
     "For the best results, please consider using a GNU/Linux server instead." : "Umjesto toga, za najbolje rezultate, molimo razmislite o mogućnosti korištenje GNU/Linux servera.",
     "Sunday" : "Nedjelja",
@@ -49,8 +54,8 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
     "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
+    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
     "Authentication error" : "Grešna autentifikacije",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator."
 },
