@@ -2,31 +2,32 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "نمیتوانید داخل دایرکتوری \"config\" تغییراتی ایجاد کنید",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "این امر معمولاً با دسترسی به نوشتن وب سرور به فهرست تنظیمات قابل حل است",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "یا اگر ترجیح می دهید پرونده config.php را فقط بخوانید ، گزینه \"config_is_read_only\" را در آن تنظیم کنید.",
     "See %s" : "مشاهده %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "یا اگر ترجیح می دهید پرونده config.php را فقط بخوانید ، گزینه \"config_is_read_only\" را در آن تنظیم کنید. دیدن%s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "فایل های برنامه %1$sبه درستی تعویض نشد. اطمینان حاصل کنید که این یک نسخه سازگار با سرور است.",
     "Sample configuration detected" : "فایل پیکربندی نمونه پیدا شد",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تشخیص داده شده است که پیکربندی نمونه کپی شده است. این می تواند نصب شما را خراب کند و پشتیبانی نمی شود. لطفاً قبل از انجام تغییرات در config.php ، اسناد را بخوانید",
+    "404" : "۴۰۴",
     "%1$s and %2$s" : "%1$sو%2$s",
     "%1$s, %2$s and %3$s" : "%1$s،%2$sو%3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s،%2$s،%3$sو%4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s،%2$s،%3$s،%4$sو%5$s",
-    "Education Edition" : "نسخه آموزش",
-    "Enterprise bundle" : "بسته نرم افزاری سازمانی",
-    "Groupware bundle" : "بسته نرم افزاری گروهی",
-    "Hub bundle" : "بسته های توپی",
-    "Social sharing bundle" : "بسته نرم افزاری اشتراک اجتماعی",
+    "Education Edition" : "نگارش آموزشی",
+    "Enterprise bundle" : "بستهٔ سازمانی",
+    "Groupware bundle" : "بستهٔ کار گروهی",
+    "Hub bundle" : "بستهٔ هسته‌ای",
+    "Social sharing bundle" : "بستهٔ هم‌رسانی اجتماعی",
     "PHP %s or higher is required." : "PHP نسخه‌ی %s یا بالاتر نیاز است.",
-    "PHP with a version lower than %s is required." : "PHP با نسخه پایین تر از مورد نیاز%s است.",
-    "%sbit or higher PHP required." : "%sکمی یا بالاتر PHP لازم است.",
+    "PHP with a version lower than %s is required." : "نیاز به نگارش پایین‌تر از %s پی‌اچ‌پی.",
+    "%sbit or higher PHP required." : "نیاز به پی‌اچ‌پی %sبیتی یا بالاتر.",
+    "The following architectures are supported: %s" : "معماری‌های زیر پشتیبانی می‌شوند: %s",
+    "The following databases are supported: %s" : "پایگاه داده‌های زیر پشتیبانی می‌شوند: %s",
     "The command line tool %s could not be found" : "ابزار کامندلاین %s پیدا نشد",
     "The library %s is not available." : "کتابخانه‌ی %s  در دسترس نیست.",
-    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%3$sکتابخانه با%1$s نسخه بالاتر از حد مورد%2$s نیاز - نسخه موجود",
-    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "%3$sکتابخانه %1$sبا نسخه پایین تر از حد مورد%2$s نیاز - نسخه موجود",
-    "Server version %s or higher is required." : "نسخه سرور%s یا بالاتر مورد نیاز است.",
-    "Server version %s or lower is required." : "نسخه سرور%sیا پایین مورد نیاز است.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "کتاب‌خانهٔ %1$s با نگارشی بالاتر از %2$s مورد نیاز است - نگارش موجود %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "کتاب‌خانهٔ %1$s با نگارشی پایین‌تر از %2$s مورد نیاز است - نگارش موجود %3$s.",
+    "The following platforms are supported: %s" : "بن‌سازه‌های زیر پشتیبانی می‌شوند: %s",
+    "Server version %s or higher is required." : "نیاز به کارساز با نگارش %s یا بالاتر.",
+    "Server version %s or lower is required." : "نیاز به کارساز با نگارش %s یا پایین‌تر.",
     "Logged in user must be an admin or sub admin" : "ورود به سیستم کاربر باید یک مدیر یا مدیر فرعی باشد",
     "Logged in user must be an admin" : "ورود به سیستم کاربر باید مدیر سایت باشد",
     "Wiping of device %s has started" : "پاک کردن دستگاه%s شروع شده است",
@@ -45,54 +46,81 @@ OC.L10N.register(
     "Unknown filetype" : "نوع فایل ناشناخته",
     "Invalid image" : "عکس نامعتبر",
     "Avatar image is not square" : "تصویر آواتار مربع نیست",
+    "View profile" : "مشاهده پروفایل",
     "today" : "امروز",
     "tomorrow" : "فردا",
     "yesterday" : "دیروز",
+    "_in %n day_::_in %n days_" : ["در ۱ روز","در %n روز"],
     "_%n day ago_::_%n days ago_" : ["%n روز پیش","%n روز پیش"],
     "next month" : "ماه آینده",
     "last month" : "ماه قبل",
+    "_in %n month_::_in %n months_" : ["در ۱ ماه","در %n ماه"],
     "_%n month ago_::_%n months ago_" : ["%n ماه قبل","%n ماه قبل"],
     "next year" : "سال آینده",
     "last year" : "سال قبل",
+    "_in %n year_::_in %n years_" : ["در ۱ سال","در %nسال"],
     "_%n year ago_::_%n years ago_" : ["%n سال پیش","%n سال پیش"],
+    "_in %n hour_::_in %n hours_" : ["در ۱ ساعت","در %n ساعت"],
     "_%n hour ago_::_%n hours ago_" : ["%n ساعت قبل","%n ساعت قبل"],
+    "_in %n minute_::_in %n minutes_" : ["در ۱ دقیقه","در %n دقیقه"],
     "_%n minute ago_::_%n minutes ago_" : ["%n دقیقه قبل","%n دقیقه قبل"],
     "in a few seconds" : "در چند ثانیه",
     "seconds ago" : "ثانیه‌ها پیش",
-    "Empty file" : "پرونده خالی",
+    "Empty file" : "پروندهٔ خالی",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ماژول با شناسه:%s وجود ندارد. لطفاً آن را در تنظیمات برنامه خود فعال کنید یا با سرپرست خود تماس بگیرید",
+    "File already exists" : "پرونده از پیش موجود است",
+    "Invalid path" : "مسیر نامعتبر",
+    "Failed to create file from template" : "شکست در ایجاد پرونده از قالب",
+    "Templates" : "قالب‌ها",
     "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
     "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
     "File name is too long" : "نام فایل خیلی بزرگ است",
-    "Dot files are not allowed" : "فایل های نقطه مجاز نیستند",
+    "Dot files are not allowed" : "پرونده‌های نقطه‌دار مجاز نیستند",
     "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "برنامه%s به دلیل نصب پرونده اطلاعات برنامه قابل نصب نیست.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "برنامه%s قابل نصب نیست زیرا با این نسخه از سرور سازگار نیست.",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "کارهٔ «%s» به دلیل ناتوانی در خواندن پروندهٔ appinfo نمی‌تواند نصب شود.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "کارهٔ «%s» به دلیل سازگار نبودن با این نگارش از کارساز نمی‌تواند نصب شود.",
     "__language_name__" : "فارسى",
-    "This is an automatically sent email, please do not reply." : "این یک ایمیل بصورت خودکار ارسال شده است ، لطفاً پاسخ ندهید.",
-    "Help" : "کمک",
+    "This is an automatically sent email, please do not reply." : "این یک رایانامهٔ خودکار است. لطفاً پاسخ ندهید.",
+    "Help" : "راه‌نما",
+    "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
     "Apps" : "  برنامه ها",
+    "Personal settings" : "تنظیمات شخصی",
+    "Administration settings" : "تنظمیات مدیریتی",
     "Settings" : "تنظیمات",
     "Log out" : "خروج",
     "Users" : "کاربران",
+    "Email" : "رایانامه",
+    "Mail %s" : "نامه به %s",
+    "Phone" : "تلفن",
+    "Call %s" : "تماس با %s",
+    "Twitter" : "توییتر",
+    "View %s on Twitter" : "دیدن %s روی توییتر",
+    "Website" : "پایگاه وب",
+    "Visit %s" : "سر زدن به %s",
+    "Address" : "نشانی",
+    "Profile picture" : "تصویر نمایه",
+    "About" : "درباره",
+    "Full name" : "نام کامل",
+    "Headline" : "عنوان",
+    "Organisation" : "سازمان",
+    "Role" : "نقش",
     "Unknown user" : "کاربر نامعلوم",
     "Additional settings" : "تنظیمات اضافی",
-    "%s enter the database username and name." : "نام کاربری و نام پایگاه داده را وارد کنید.%s",
-    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
-    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
-    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
-    "You need to enter details of an existing account." : "شما باید جزئیات یک حساب موجود را وارد کنید.",
+    "Enter the database username and name for %s" : "ورود نام و نام کاربری پایگاه داده برای %s",
+    "Enter the database username for %s" : "ورود نام کاربری پایگاه داده برای %s",
+    "Enter the database name for %s" : "ورود نام پایگاه داده برای %s",
+    "You cannot use dots in the database name %s" : "نمی‌توانید در در نام پایگاه دادهٔ %s از نقطه استفاده کنید",
+    "MySQL username and/or password not valid" : "نام کاربری یا گذرواژهٔ مای‌سکول معتبر نیست",
+    "You need to enter details of an existing account." : "لازم است جزییات یک حساب موحود را وارد کنید.",
     "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
     "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
     "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X پشتیبانی نمی شود و %sبه درستی روی این پلتفرم کار نخواهد کرد. از خطر آن استفاده کنید!",
-    "For the best results, please consider using a GNU/Linux server instead." : "برای بهترین نتیجه ، لطفاً به جای آن از سرور GNU / Linux در نظر بگیرید.",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "مک‌اواس ۱۰ پشتیبانی نشده و %s روی این بن‌سازه درست کار نخواهد کرد. با مسئولیت خودتان استفاده کنید!",
+    "For the best results, please consider using a GNU/Linux server instead." : "برای بهترین نتیجه، استفاده از یک کارساز گنو/لینوکسی را در نظر داشته باشید.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "به نظر می رسد%s که این نمونه در یک محیط PHP 32 بیتی در حال اجرا است و open_baseir در php.ini پیکربندی شده است. این مسئله به پرونده هایی با بیش از 4 گیگ منجر می شود و بسیار دلسرد می شود",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "لطفاً تنظیمات open_baseir را درون php.ini خود حذف کنید یا به PHP 64 بیتی تغییر دهید.",
     "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
     "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
-    "Can't create or write into the data directory %s" : "%sنمی توانید در فهرست داده ایجاد یا نوشتن کنید",
-    "Invalid Federated Cloud ID" : "شناسه فدرال شده با ابر Cloud",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "به اشتراک گذاشتن باطن باید رابط OCP \\ Share_Backend %sرا پیاده سازی کند",
     "Sharing backend %s not found" : "به اشتراک گذاشتن باطن%s یافت نشد",
     "Sharing backend for %s not found" : "به اشتراک گذاشتن باطن برای%s یافت نشد",
@@ -102,105 +130,85 @@ OC.L10N.register(
     "Open »%s«" : "باز کن »%s«",
     "%1$s via %2$s" : "%1$s از طریق %2$s",
     "You are not allowed to share %s" : "شما مجاز به اشتراک گذاری نیستید%s",
-    "Can’t increase permissions of %s" : "مجوزها را نمی توان افزایش داد%s",
-    "Files can’t be shared with delete permissions" : "فایلها را نمی توان با مجوزهای حذف حذف کرد",
-    "Files can’t be shared with create permissions" : "فایلها را نمی توان با ایجاد مجوزها به اشتراک گذاشت",
     "Expiration date is in the past" : "تاریخ انقضا در گذشته است",
-    "Can’t set expiration date more than %s days in the future" : "نمی توان تاریخ انقضا را بیش%s از روزها در آینده تعیین کرد",
     "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
     "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
     "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
     "The requested share does not exist anymore" : "سهم درخواست شده دیگر وجود ندارد",
     "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
-    "Sunday" : "یکشنبه",
+    "Sunday" : "یک‌شنبه",
     "Monday" : "دوشنبه",
-    "Tuesday" : "سه شنبه",
+    "Tuesday" : "سه‌شنبه",
     "Wednesday" : "چهارشنبه",
-    "Thursday" : "پنجشنبه",
-    "Friday" : "جمعه",
+    "Thursday" : "پنج‌شنبه",
+    "Friday" : "آدینه",
     "Saturday" : "شنبه",
-    "Sun." : "یکشنبه",
-    "Mon." : "دوشنبه",
-    "Tue." : "سه شنبه",
-    "Wed." : "چهارشنبه",
-    "Thu." : "پنج شنبه",
-    "Fri." : "جمعه",
-    "Sat." : "شنبه",
-    "Su" : "یک‌شنبه",
-    "Mo" : "دوشنبه",
-    "Tu" : "سه‌شنبه",
-    "We" : "چهار‌شنبه",
-    "Th" : "پنج‌شنبه",
-    "Fr" : "جمعه",
-    "Sa" : "شنبه",
+    "Sun." : "یک.",
+    "Mon." : "دو.",
+    "Tue." : "سه.",
+    "Wed." : "چهار.",
+    "Thu." : "پنج.",
+    "Fri." : "آد.",
+    "Sat." : "شن.",
+    "Su" : "ی",
+    "Mo" : "د",
+    "Tu" : "س",
+    "We" : "چ",
+    "Th" : "پ",
+    "Fr" : "آ",
+    "Sa" : "ش",
     "January" : "ژانویه",
-    "February" : "فبریه",
+    "February" : "فوریه",
     "March" : "مارس",
     "April" : "آوریل",
-    "May" : "می",
+    "May" : "مه",
     "June" : "ژوئن",
     "July" : "جولای",
-    "August" : "آگوست",
+    "August" : "اوت",
     "September" : "سپتامبر",
     "October" : "اکتبر",
     "November" : "نوامبر",
     "December" : "دسامبر",
-    "Jan." : "ژانویه",
-    "Feb." : "فوریه",
-    "Mar." : "مارچ",
-    "Apr." : "آوریل",
-    "May." : "می",
-    "Jun." : "ژوئن",
-    "Jul." : "جولای",
-    "Aug." : "آگوست",
-    "Sep." : "سپتامبر",
-    "Oct." : "اکتبر",
-    "Nov." : "نوامبر",
-    "Dec." : "دسامبر",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "فقط کاراکترهای زیر در نام کاربری مجاز هستند: \"a-z\" ، \"A-Z\" ، \"0-9\" و \"_. @ - '\"",
+    "Jan." : "ژان.",
+    "Feb." : "فو.",
+    "Mar." : "مار.",
+    "Apr." : "آو.",
+    "May." : "مه.",
+    "Jun." : "ژو.",
+    "Jul." : "جول.",
+    "Aug." : "اوت.",
+    "Sep." : "سپ.",
+    "Oct." : "اکت.",
+    "Nov." : "نو.",
+    "Dec." : "دس.",
+    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
+    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
+    "Could not create user" : "نتواسنت کاربر را ایجاد کند",
     "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
     "Username contains whitespace at the beginning or at the end" : "نام کاربری دارای فضای سفید در ابتدا یا انتهای آن است",
     "Username must not consist of dots only" : "نام کاربری نباید فقط از نقاط تشکیل شده باشد",
-    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
-    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
-    "Could not create user" : "کاربر ایجاد نشد",
-    "User disabled" : "کاربر غیرفعال",
-    "Login canceled by app" : "ورود به سیستم توسط برنامه لغو شد",
-    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "%2$sبرنامه %1$sنصب نمی شود زیرا وابستگی های زیر برآورده نشده است:",
-    "a safe home for all your data" : "خانه ای امن برای تمام داده های شما",
+    "User disabled" : "کاربر از کار افتاده",
+    "Login canceled by app" : "ورود به دست کاره لغو شد",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "کارهٔ «%1$s» نمی‌تواند نصب شود؛ چرا که وابستگی زیر تأمین نشده: %2$s",
+    "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
     "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
-    "Can't read file" : "امکان خواندن فایل وجود ندارد",
+    "Cannot download file" : "نمی‌توان پرونده را بارگرفت",
     "Application is not enabled" : "برنامه فعال نشده است",
     "Authentication error" : "خطا در اعتبار سنجی",
     "Token expired. Please reload page." : "Token منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "هیچ درایور پایگاه داده (sqlite ، mysql یا postgresql) نصب نشده است.",
-    "Cannot write into \"config\" directory" : "امکان نوشتن درون شاخه‌ی \"config\" وجود ندارد",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "%sاین امر معمولاً با دسترسی به نوشتن وب سرور به فهرست تنظیمات قابل حل است. دیدن",
-    "Cannot write into \"apps\" directory" : "نمی توان در فهرست \"برنامه ها\" نوشت",
-    "Cannot create \"data\" directory" : "دایرکتوری \"داده\" ایجاد نمی شود",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "این امر معمولاً با دسترسی به نوشتن وب سرور به فهرست اصلی قابل حل است. دیدن%s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "معمولاً مجوزها می توانند با دسترسی به نوشتن وب سرور به فهرست اصلی ، ثابت شوند. دیدن%s",
-    "Setting locale to %s failed" : "تنظیم محلی در %sانجام نشد",
-    "Please install one of these locales on your system and restart your webserver." : "لطفاً یکی از این لوکال ها را روی سیستم خود نصب کرده و شبکه سرور خود را مجدداً راه اندازی کنید.",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "یا اگر ترجیح می دهید پرونده config.php را فقط بخوانید ، گزینه \"config_is_read_only\" را در آن تنظیم کنید. دیدن%s",
     "PHP module %s not installed." : "ماژول PHP %s نصب نشده است.",
     "Please ask your server administrator to install the module." : "لطفا از مدیر سیستم بخواهید تا ماژول را نصب کند.",
     "PHP setting \"%s\" is not set to \"%s\"." : "تنظیمات PHP%s تنظیم نشده است%s",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "تنظیم این تنظیمات در php.ini باعث می شود Nextcloud دوباره اجرا شود",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload به جای %sمقدار مورد انتظار تنظیم شده است",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "برای رفع این<code> مشکل ، mbstring.func_overload </code>را <code>0 </code>در php.ini خود تنظیم کنید",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 حداقل مورد نیاز است. در حال حاضر %sنصب شده است",
     "To fix this issue update your libxml2 version and restart your web server." : "برای رفع این مشکل نسخه libxml2 خود را به روز کنید و سرور وب خود را مجدداً راه اندازی کنید.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ظاهراً برای خنثی کردن بلوک های اسناد درون خطی تنظیم شده است. این کار چندین برنامه اصلی را غیرقابل دسترسی خواهد کرد.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "این احتمالاً توسط حافظه پنهان / کش مانند Zend OPcache یا eAccelerator ایجاد شده است.",
     "PHP modules have been installed, but they are still listed as missing?" : "ماژول های پی اچ پی نصب شده اند ، اما هنوز هم به عنوان مفقود شده ذکر شده اند؟",
     "Please ask your server administrator to restart the web server." : "لطفاً از سرور سرور خود بخواهید که وب سرور را مجدداً راه اندازی کند.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 نیاز است",
-    "Please upgrade your database version" : "لطفا نسخه‌ی پایگاه‌داده‌ی خود را بروز کنید",
-    "Your data directory is readable by other users" : "فهرست داده های شما توسط سایر کاربران قابل خواندن است",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود.",
-    "Your data directory must be an absolute path" : "فهرست داده های شما باید مسیری مطلق باشد",
-    "Check the value of \"datadirectory\" in your configuration" : "مقدار \"datadirectory\" را در پیکربندی خود بررسی کنید",
-    "Your data directory is invalid" : "فهرست داده شما نامعتبر است",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "اطمینان حاصل کنید که فایلی به نام \".ocdata\" در ریشه دایرکتوری داده وجود دارد.",
     "Action \"%s\" not supported or implemented." : "عملی%s پشتیبانی یا اجرا نشده است.",
     "Authentication failed, wrong token or provider ID given" : "تأیید اعتبار انجام نشد ، نشانه اشتباه یا شناسه ارائه دهنده داده شد",
@@ -213,15 +221,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "خطای اتصال ذخیره سازی%s",
     "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
     "Storage connection timeout. %s" : "مدت زمان اتصال ذخیره سازی%s",
-    "Following databases are supported: %s" : "پایگاه‌داده‌ های ذکر شده مورد نیاز است: %s",
-    "Following platforms are supported: %s" : "سیستم عامل های زیر پشتیبانی می شوند%s",
-    "Overview" : "بررسی اجمالی",
-    "Basic settings" : "تنظیمات پایه",
-    "Sharing" : "اشتراک گذاری",
-    "Security" : "امنیت",
-    "Groupware" : "گروه های نرم افزاری",
-    "Personal info" : "مشخصات شخصی",
-    "Mobile & desktop" : "موبایل و دسک تاپ",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "این امر معمولاً با دسترسی به وب سرور دسترسی به فهرست برنامه ها یا غیرفعال کردن برنامه در پرونده پیکربندی قابل رفع است. دیدن%s"
+    "%s enter the database username and name." : "نام کاربری و نام پایگاه داده را وارد کنید.%s",
+    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
+    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
+    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "تنها نویسه‌ها زیر در نام کاربری مجازند: \"a-z\" ، \"A-Z\" ، \"0-9\" و \"_. @ - '\""
 },
 "nplurals=2; plural=(n > 1);");
