@@ -2,12 +2,17 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Kan niet schrijven naar de \"config\" directory!",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Dit kan opgelost worden door de config map op de webserver schrijfrechten te geven.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Dit kan opgelost worden door de config map op de webserver schrijfrechten te geven.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Maar, als je liever config.php alleen-lezen wilt houden, stel dan de optie \"config_is_read_only\" in op true.",
     "See %s" : "Zie %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "De bestanden van app %1$szijn niet correct vervangen. Zorg ervoor dat de versie compatible is met de server.",
     "Sample configuration detected" : "Voorbeeld configuratie gevonden",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Er is gedetecteerd dat de voorbeeld configuratie is gekopieerd. Dit kan je installatie beschadigen en wordt dan ook niet ondersteund. Lees de documentatie voordat je wijzigingen aan config.php doorvoert",
+    "%s email verification" : "%s e-mail verificatie",
+    "Email verification" : "E-mail verificatie",
+    "Click the following button to confirm your email." : "Klik op de knop om je e-mail te bevestigen.",
+    "Click the following link to confirm your email." : "Klik op de volgende link om je e-mail te bevestigen.",
+    "Confirm your email" : "Bevestig je e-mailadres",
     "Other activities" : "Andere activiteiten",
     "%1$s and %2$s" : "%1$s en %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s en %3$s",
@@ -30,6 +35,7 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "De volgende platforms worden ondersteund: %s",
     "Server version %s or higher is required." : "Serverversie %s of hoger vereist.",
     "Server version %s or lower is required." : "Serverversie %s of lager vereist.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Ingelogde gebruiken moet beheerder, sub-beheerder of gebruiker met speciale rechten om deze instelling te veranderen zijn",
     "Logged in user must be an admin or sub admin" : "Ingelogde gebruiker moet een beheerder of subbeheerder zijn",
     "Logged in user must be an admin" : "Ingelogde gebruiker moet een beheerder zijn",
     "Wiping of device %s has started" : "Leegmaken van toestel %sis gestart",
@@ -48,6 +54,7 @@ OC.L10N.register(
     "Unknown filetype" : "Onbekend bestandsformaat",
     "Invalid image" : "Ongeldige afbeelding",
     "Avatar image is not square" : "Avatar afbeelding is niet vierkant",
+    "View profile" : "Bekijk profiel",
     "today" : "vandaag",
     "tomorrow" : "morgen",
     "yesterday" : "gisteren",
@@ -83,16 +90,29 @@ OC.L10N.register(
     "__language_name__" : "Nederlands",
     "This is an automatically sent email, please do not reply." : "Dit is een automatisch gegenereerde e-mail, dus reageren is niet mogelijk.",
     "Help" : "Help",
+    "Appearance and accessibility" : "Weergave en toegankelijkheid",
     "Apps" : "Apps",
+    "Personal settings" : "Persoonlijke instellingen",
     "Settings" : "Instellingen",
     "Log out" : "Uitloggen",
     "Users" : "Gebruikers",
+    "Email" : "E-mail",
+    "Mail %s" : "Mail %s",
+    "Phone" : "Telefoon",
+    "Call %s" : "Bel %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Bekijk %s op Twitter",
+    "Website" : "Website",
+    "Visit %s" : "Bezoek %s",
+    "Address" : "Adres",
+    "Profile picture" : "Profielafbeelding",
+    "About" : "Over",
+    "Full name" : "Volledige naam",
+    "Headline" : "Hoofdlijn",
+    "Organisation" : "Organisatie",
+    "Role" : "Rol",
     "Unknown user" : "Onbekende gebruiker",
     "Additional settings" : "Aanvullende instellingen",
-    "%s enter the database username and name." : "%s voer de database gebruikersnaam en naam in .",
-    "%s enter the database username." : "%s voer de database gebruikersnaam in.",
-    "%s enter the database name." : "%s voer de databasenaam in.",
-    "%s you may not use dots in the database name" : "%s er mogen geen punten in de databasenaam voorkomen",
     "MySQL username and/or password not valid" : "MySQL gebruikersnaam en/of wachtwoord ongeldig",
     "You need to enter details of an existing account." : "Geef de details van een bestaand account op.",
     "Oracle connection could not be established" : "Er kon geen verbinding met Oracle worden gemaakt.",
@@ -114,9 +134,9 @@ OC.L10N.register(
     "Open »%s«" : "Open \"%s\"",
     "%1$s via %2$s" : "%1$s via %2$s",
     "You are not allowed to share %s" : "Je bent niet bevoegd om %s te delen",
-    "Cannot increase permissions of %s" : "Kan de rechten van %s niet verhogen.",
-    "Files cannot be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijder permissies",
-    "Files cannot be shared with create permissions" : "Bestanden kunnen niet worden gedeeld met 'creëer' permissies",
+    "Cannot increase permissions of %s" : "Kan de machtiging van %s niet verhogen.",
+    "Files cannot be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijdermachtigingen",
+    "Files cannot be shared with create permissions" : "Bestanden kunnen niet worden gedeeld met creëermachtigingen",
     "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan de vervaldatum niet meer dan %s dag in de toekomst instellen","Kan de vervaldatum niet meer dan %s dagen in de toekomst instellen"],
     "Sharing is only allowed with group members" : "Delen kan alleen met groepsleden",
@@ -171,54 +191,52 @@ OC.L10N.register(
     "Oct." : "Okt.",
     "Nov." : "Nov.",
     "Dec." : "Dec.",
-    "The user limit has been reached and the user was not created." : "Het maximum aantal gebruikers is bereikt en de gebruiker is niet aangemaakt.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Alleen de volgende tekens zijn toegestaan in een gebruikersnaam: \"a-z\", \"A-Z\", \"0-9\", en \"_.@-\"",
+    "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
+    "The username is already being used" : "De gebruikersnaam bestaat al",
+    "Could not create user" : "Kan gebruiker niet aanmaken.",
     "A valid username must be provided" : "Er moet een geldige gebruikersnaam worden opgegeven",
     "Username contains whitespace at the beginning or at the end" : "De gebruikersnaam bevat spaties aan het begin of aan het eind",
     "Username must not consist of dots only" : "De gebruikersnaam mag niet uit alleen punten bestaan",
     "Username is invalid because files already exist for this user" : "Gebruikersnaam is ongeldig omdat er al bestanden voor deze gebruiker bestaan",
-    "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
-    "The username is already being used" : "De gebruikersnaam bestaat al",
-    "Could not create user" : "Kan gebruiker niet aanmaken.",
-    "User disabled" : "Gebruiker geblokkeerd",
+    "User disabled" : "Gebruiker uitgeschakeld",
     "Login canceled by app" : "Inloggen geannuleerd door app",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld: %2$s",
     "a safe home for all your data" : "een veilige plek voor al je gegevens",
     "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
-    "Cannot read file" : "Kan bestand niet lezen",
     "Application is not enabled" : "De applicatie is niet ingeschakeld",
     "Authentication error" : "Authenticatiefout",
     "Token expired. Please reload page." : "Token verlopen.  Herlaad de pagina.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Geen database drivers (sqlite, mysql of postgres) geïnstalleerd.",
-    "Cannot write into \"config\" directory" : "Kan niet schrijven naar de \"config\" directory",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dit kan opgelost worden door de config map op de webserver schrijf rechten te geven. See %s",
+    "Cannot write into \"config\" directory." : "Kan niet schrijven naar de \"config\" directory!",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dit kan opgelost worden door de config map op de webserver schrijf rechten te geven. Zie %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Of, als je liever config.php Alleen-lezen houdt, stel de optie  \"config_is_read_only\" in op true. Zie %s",
-    "Cannot write into \"apps\" directory" : "Kan niet schrijven naar de \"apps\" directory",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
-    "Cannot create \"data\" directory" : "\"data\" map kan niet worden aangemaakt",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Dit kan hersteld worden door de root map schrijf rechten te geven op de webserver. Zie %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Rechten kunnen worden hersteld door de root map op de webserver schrijf toegang te geven. Zie %s.",
-    "Setting locale to %s failed" : "Instellen taal op %s mislukte",
-    "Please install one of these locales on your system and restart your webserver." : "Installeer één van de talen op je systeem en herstart je webserver.",
+    "Cannot write into \"apps\" directory." : "Kan niet schrijven naar de \"apps\" directory",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
+    "Cannot create \"data\" directory." : "Kan de \"data\"-map niet aanmaken.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dit kan hersteld worden door de root map schrijf rechten te geven op de webserver. Zie %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Machtigingen kunnen worden hersteld door de root map op de webserver schrijf toegang te geven. Zie %s.",
+    "Your data directory is not writable." : "Je datamap is niet beschrijfbaar",
+    "Setting locale to %s failed." : "Instellen taal op %s mislukte.",
+    "Please install one of these locales on your system and restart your web server." : "Installeer één van de talen op je systeem en herstart je webserver.",
     "PHP module %s not installed." : "PHP module %s niet geïnstalleerd.",
     "Please ask your server administrator to install the module." : "Vraag je beheerder om de module te installeren.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP instelling \"%s\" staat niet op \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Het aanpassen van deze instelling in php.ini zorgt ervoor dat Nextcloud weer start",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is ingesteld op \"%s\" in plaats van de verwachte waarde \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Om dit probleem op te lossen stel je in php.ini <code>mbstring.func_overload</code> in op <code>0</code>",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is ingesteld op <code>%s</code> in plaats van de verwachte waarde <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Om dit op te lossen stel je <code>mbstring.func_overload</code> in op <code>0</code> in je php.ini.",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "De minimale versie van libxml2 versie is 2.7.0. Momenteel is  versie%s geïnstalleerd.",
     "To fix this issue update your libxml2 version and restart your web server." : "Om dit probleem op te lossen, moet je de libxml2 versie bijwerken en je webserver herstarten.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is nu zo ingesteld dat 'inline doc blocks' worden gestript. Hierdoor worden verschillende hoofd modules onbruikbaar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar ze worden nog steeds als ontbrekend aangegeven?",
     "Please ask your server administrator to restart the web server." : "Vraag je beheerder de webserver opnieuw te starten.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 is vereist",
-    "Please upgrade your database version" : "Werk je databaseversie bij",
-    "Your data directory is readable by other users" : "Je datamap is leesbaar voor andere gebruikers",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de permissie in 0770 zodat de directory niet door andere gebruikers bekeken kan worden.",
-    "Your data directory must be an absolute path" : "Je datamap moet een absolute bestandslocatie hebben",
-    "Check the value of \"datadirectory\" in your configuration" : "Controleer de waarde van \"datadirectory\" in je configuratie",
-    "Your data directory is invalid" : "Je datamap is ongeldig",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 is vereist.",
+    "Please upgrade your database version." : "Werk je databaseversie bij.",
+    "Your data directory is readable by other users." : "Je datamap is leesbaar voor andere gebruikers.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de machtiging in 0770 zodat de directory niet door andere gebruikers bekeken kan worden.",
+    "Your data directory must be an absolute path." : "Je datamap moet een absolute bestandslocatie hebben.",
+    "Check the value of \"datadirectory\" in your configuration." : "Controleer de waarde van \"datadirectory\" in je configuratie.",
+    "Your data directory is invalid." : "Je datamap is ongeldig.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Zorg dat er een bestand genaamd \".ocdata\" in de hoofddirectory aanwezig is.",
     "Action \"%s\" not supported or implemented." : "Actie \"%s\" niet ondersteund of geïmplementeerd.",
     "Authentication failed, wrong token or provider ID given" : "Authenticatie mislukt, ongeldig token of provider ID opgegeven",
@@ -231,15 +249,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "Opslag verbindingsfout. %s",
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage connection timeout. %s" : "Opslag verbinding time-out. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Dit kan opgelost worden door de config map op de webserver schrijfrechten te geven",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Of, als je liever config.php alleen-lezen wilt houden, stel de optie \"config_is_read_only\" in op true.",
-    "Can't create or write into the data directory %s" : "Kan niets creëren of wegschrijven in de datadirectory %s",
-    "Invalid Federated Cloud ID" : "Ongeldige gefedereerde Cloud ID",
-    "Can’t increase permissions of %s" : "Kan niet meer rechten geven aan %s",
-    "Files can’t be shared with delete permissions" : "Bestanden kunnen niet worden gedeeld met verwijder permissies",
-    "Files can’t be shared with create permissions" : "Bestanden kunnen niet worden gedeeld met 'creëer' permissies",
-    "Can’t set expiration date more than %s days in the future" : "Kan de vervaldatum niet meer dan %s dagen in de toekomst instellen",
-    "Can't read file" : "Kan bestand niet lezen",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de appstore te deactiveren in het configuratie bestand."
+    "%s enter the database username and name." : "%s voer de database gebruikersnaam en naam in .",
+    "%s enter the database username." : "%s voer de database gebruikersnaam in.",
+    "%s enter the database name." : "%s voer de databasenaam in.",
+    "%s you may not use dots in the database name" : "%s er mogen geen punten in de databasenaam voorkomen",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Alleen de volgende tekens zijn toegestaan in een gebruikersnaam: \"a-z\", \"A-Z\", \"0-9\", en \"_.@-\""
 },
 "nplurals=2; plural=(n != 1);");
