@@ -8,6 +8,8 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %1$s não foram instalados corretamente. Certifique-se que é uma versão compatível com seu servidor.",
     "Sample configuration detected" : "Configuração de exemplo detectada",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
+    "404" : "404",
+    "The page could not be found on the server." : "A página não pôde ser encontrada no servidor.",
     "%s email verification" : "%s e-mail de verificação",
     "Email verification" : "E-mail de verificação",
     "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu e-mail.",
@@ -55,6 +57,7 @@ OC.L10N.register(
     "Invalid image" : "Imagem inválida",
     "Avatar image is not square" : "A imagem do avatar não é quadrada",
     "View profile" : "Visualizar perfil",
+    "Local time: %s" : "Hora local: %s",
     "today" : "hoje",
     "tomorrow" : "amanhã",
     "yesterday" : "ontem",
@@ -99,6 +102,8 @@ OC.L10N.register(
     "Users" : "Usuários",
     "Email" : "E-mail",
     "Mail %s" : "E-Mail %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Ver %s no fediverse",
     "Phone" : "Fone",
     "Call %s" : "Chamar %s",
     "Twitter" : "Twitter",
@@ -114,6 +119,10 @@ OC.L10N.register(
     "Role" : "Função",
     "Unknown user" : "Usuário desconhecido",
     "Additional settings" : "Configurações adicionais",
+    "Enter the database username and name for %s" : "Digite o nome de usuário e o nome do banco de dados para %s",
+    "Enter the database username for %s" : "Digite o nome de usuário do banco de dados para %s",
+    "Enter the database name for %s" : "Digite o nome do banco de dados para %s",
+    "You cannot use dots in the database name %s" : "Você não pode usar pontos no nome do banco de dados %s",
     "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
     "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
@@ -146,6 +155,7 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
     "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
     "The requested share does not exist anymore" : "O compartilhamento solicitado não existe mais",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "O usuário não foi criado porque o limite de usuários foi atingido. Confira suas notificações para saber mais.",
     "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
@@ -192,15 +202,14 @@ OC.L10N.register(
     "Oct." : "Out.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
-    "The user limit has been reached and the user was not created." : "O limite de usuários foi atingido e o usuário não foi criado.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
+    "A valid password must be provided" : "Uma senha válida deve ser fornecida",
+    "The username is already being used" : "Este nome de usuário já está em uso",
+    "Could not create user" : "Não foi possível criar o usuário",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", espaços e \"_.@-'\"",
     "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
     "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
     "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
     "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
-    "A valid password must be provided" : "Uma senha válida deve ser fornecida",
-    "The username is already being used" : "Este nome de usuário já está em uso",
-    "Could not create user" : "Não foi possível criar o usuário",
     "User disabled" : "Usuário desativado",
     "Login canceled by app" : "Login cancelado pelo aplicativo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
@@ -255,28 +264,11 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
     "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Geralmente, isso pode ser corrigido concedendo ao servidor web acesso de gravação ao diretório de configuração.",
     "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
     "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
     "%s enter the database name." : "%s insira o nome do banco de dados.",
     "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
-    "Cannot read file" : "Não foi possível ler o arquivo",
-    "Cannot write into \"config\" directory" : "Não foi possível gravar no diretório \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escritura no diretório config. Veja %s",
-    "Cannot write into \"apps\" directory" : "Não foi possível gravar no diretório \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido fornecendo ao servidor da web acesso de gravação ao diretório de aplicativos ou desativando a App Store no arquivo de configuração.",
-    "Cannot create \"data\" directory" : "Não foi possível criar o diretório \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escrita no diretório raiz. Veja %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "As permissões normalmente podem ser corrigidas dando permissão de escrita do diretório raiz para o servidor web. Veja %s.",
-    "Setting locale to %s failed" : "Falha ao configurar localização para %s",
-    "Please install one of these locales on your system and restart your webserver." : "Por favor, defina uma dessas localizações em seu sistema e reinicie o seu servidor web.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está definido para \"%s\" ao invés do valor esperado \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir esse problema defina <code>mbstring.func_overload</code> para <code>0</code> em seu php.ini",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
-    "Please upgrade your database version" : "Por favor atualize sua versão do banco de dados",
-    "Your data directory is readable by other users" : "O diretório de dados está legível para outros usuários",
-    "Your data directory must be an absolute path" : "O diretório de dados deve ser um caminho absoluto",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"datadirectory\" na sua configuração",
-    "Your data directory is invalid" : "Seu diretório de dados é inválido"
+    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "O limite de usuários foi atingido e o usuário não foi criado. Verifique suas notificações para saber mais.",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\""
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
